<p><-- Begin file 25 of 26:  Letter Y (Version 0.48) 
        
           This file is part 25 of the GNU version of
     The Collaborative International Dictionary of English
               Also referred to as GCIDE
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 

GCIDE is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GCIDE is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this copy of GCIDE; see the file COPYING.  If not, write 
to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.
           * * * * * * * * * * * * * * * * * * * * * 

           This dictionary was derived from the
         Webster's Revised Unabridged Dictionary
                 Version published 1913
               by the  C. & G. Merriam Co.
                   Springfield, Mass.
                 Under the direction of
                Noah Porter, D.D., LL.D.

                        and from
           WordNet, a semantic network created by
              the Cognitive Science Department
                 of Princeton University
                  under the direction of
                   Prof. George Miller

             and is being updated and supplemented by
         an open coalition of volunteer collaborators from
                       around the world.

     This electronic dictionary is the starting point for an 
ongoing project to develop a modern on-line comprehensive encyclopedic
dictionary, by the efforts of all individuals willing to help build a
large and freely available knowledge base.  Contributions of data,
time, and effort are requested from any person willing to assist creation
of a comprehensive and organized knowledge base for free access on the
internet.  Anyone willing to assist in any way in constructing such a
knowledge base should contact:

     Patrick Cassidy          pc@worldsoul.org
     735 Belvidere Ave.       Office: (908)668-5252
     Plainfield, NJ 07062
     (908) 561-3416

   Last edit October 6, 2002.

--></p>

<p><centered><point26>Y.</point26></centered><br/
[<source>1913 Webster</source>]</p>

<p><ent>Y</ent><br/
<hw>Y</hw> <pr>(w<imac/)</pr>. <def>Y, the twenty-fifth letter of the English alphabet, at the beginning of a word or syllable, except when a prefix (see Y-), is usually a fricative vocal consonant; as a prefix, and usually in the middle or at the end of a syllable, it is a vowel.  See <xex>Guide to Pronunciation</xex>, <sect/<sect/ 145, 178-9, 272.</def><br/
[<source>1913 Webster</source>]</p>

<p><note> It derives its form from the Latin Y, which is from the Greek <UPSILON/, originally the same letter as V. Etymologically, it is most nearly related to <xex>u</xex>, <xex>i</xex>, <xex>o</xex>, and <xex>j</xex>. <xex>g</xex>; as in <xex>full</xex>, <xex>fill</xex>, AS. <xex>fyllan</xex>; E. <xex>crypt</xex>, <xex>grotto</xex>; <xex>young</xex>, <xex>juvenile</xex>; <xex>day</xex>, AS. <xex>d<ae/g</xex>.  See <er>U</er>, <er>I</er>, and <er>J</er>, <er>G</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Y has been called the <xex>Pythagorean letter</xex>, because the Greek letter <UPSILON/ was taken to represent the sacred triad, formed by the duad proceeding from the monad; and also because it represents the dividing of the paths of vice and virtue in the development of human life.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Y</ent><br/
<hw>Y</hw> <pr>(w<imac/)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Y's</plw> <pr>(w<imac/z)</pr> <it>or</it> <plw>Ys</plw>.</plu> <def>Something shaped like the letter <universbold>Y</universbold>; a forked piece resembling in form the letter <universbold>Y</universbold>.</def>  <specif>Specifically:</specif> <sd>(a)</sd> <def>One of the forked holders for supporting the telescope of a leveling instrument, or the axis of a theodolite; a wye.</def>  <sd>(b)</sd> <def>A forked or bifurcated pipe fitting.</def>  <sd>(c)</sd> <fld>(Railroads)</fld> <def>A portion of track consisting of two diverging tracks connected by a cross track.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Y level</b></col> <fld>(Surv.)</fld>, <cd>an instrument for measuring differences of level by means of a telescope resting in <universbold>Y</universbold>'s.</cd> -- <col><b>Y moth</b></col> <fld>(Zool.)</fld>, <cd>a handsome European noctuid moth <spn>Plusia gamma</spn>) which has a bright, silvery mark, shaped like the letter <universbold>Y</universbold>, on each of the fore wings. Its larva, which is green with five dorsal white species, feeds on the cabbage, turnip, bean, etc. Called also <altname>gamma moth</altname>, and <altname>silver Y</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Y</ent><br/
<hw>Y</hw> <pr>(<imac/)</pr>, <pos>pron.</pos> <def>I.</def>  <mark>[Obs.]</mark>  <rj><au>King Horn.</au>  <au>Wyclif.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>I-</ent><br/
<ent>Y-</ent><br/
<mhw>{ <hw>Y-</hw> <pr>(?)</pr>, <it>or</it> <hw>I-</hw>  }</mhw>. <ety>[OE. <ets>y-</ets>, <ets>i-</ets>, AS. <ets>ge-</ets>, akin to D. & G. <ets>ge-</ets>, OHG. <ets>gi-</ets>, <ets>ga-</ets>, Goth. <ets>ga-</ets>, and perhaps to Latin <ets>con</ets>-; originally meaning, together.  Cf. <er>Com-</er>, <er>Aware</er>, <er>Enough</er>, <er>Handiwork</er>, <er>Ywis</er>.]</ety> <def>A prefix of obscure meaning, originally used with verbs, adverbs, adjectives, nouns, and pronouns. In the Middle English period, it was little employed except with verbs, being chiefly used with past participles, though occasionally with the infinitive.  <xex>Ycleped</xex>, or <xex>yclept</xex>, is perhaps the only word not entirely obsolete which shows this use.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>That no wight mighte it see neither <qex>y</qex>heere.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Neither to ben <qex>y</qex>buried nor <qex>y</qex>brent.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Some examples of Chaucer's use of this prefix are; <xex>i</xex>be, <xex>i</xex>been, <xex>i</xex>caught, <xex>y</xex>come, <xex>y</xex>do, <xex>i</xex>doon, <xex>y</xex>go, <xex>i</xex>proved, <xex>y</xex>wrought. It <xex>i</xex>nough, <xex>e</xex>nough, it is combined with an adjective. Other examples are in the Vocabulary.<br/
[<source>1913 Webster</source>]</p>

<p>   Spenser and later writers frequently employed this prefix when affecting an archaic style, and sometimes used it incorrectly.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ya</ent><br/
<hw>Ya</hw> <pr>(y<aum/)</pr>, <pos>adv.</pos> <def>Yea.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yacare</ent><br/
<hw>Yac"a*re`</hw> <pr>(y<acr/k"<adot/*r<amac/`)</pr>, <pos>n.</pos> <ety>[See <ets>Jacare</ets>.]</ety> <fld>(Zool.)</fld> <def>A South American crocodilian (<spn>Jacare sclerops</spn>) resembling the alligator in size and habits. The eye orbits are connected together, and surrounded by prominent bony ridges. Called also <altname>spectacled alligator</altname>, and <altname>spectacled cayman</altname>.</def>  <altsp>[Written also <asp>jacare</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The name is also applied to allied species.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yacca</ent><br/
<hw>Yac"ca</hw> <pr>(y<acr/k"k<adot/)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A West Indian name for two large timber trees (<spn>Podocarpus coriaceus</spn>, and <spn>Podocarpus Purdicanus</spn>) of the Yew family. The wood, which is much used, is pale brownish with darker streaks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yacht</ent><br/
<hw>Yacht</hw> <pr>(y<ocr/t)</pr>, <pos>n.</pos> <ety>[D. <ets>jagt</ets>, <ets>jacht</ets>; perhaps properly, a chase, hunting, from. <ets>jagen</ets> to chase, hunt, akin to G. <ets>jagen</ets>, OHG. <ets>jag<omac/n</ets>, of uncertain origin; or perhaps akin to OHG. <ets>g<amac/hi</ets> quick, sudden (cf. <er>Gay</er>).]</ety> <fld>(Naut.)</fld> <def>A light and elegantly furnished vessel, used either for private parties of pleasure, or as a vessel of state to convey distinguished persons from one place to another; a seagoing vessel used only for pleasure trips, racing, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yacht measurement</b></col>. <cd>See the Note under <er>Tonnage</er>, 4.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yacht</ent><br/
<hw>Yacht</hw>, <pos>v. i.</pos> <def>To manage a yacht; to voyage in a yacht.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yachter</ent><br/
<hw>Yacht"er</hw> <pr>(-<etil/r)</pr>, <pos>n.</pos> <def>One engaged in sailing a yacht.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yachting</ent><br/
<hw>Yacht"ing</hw>, <pos>n.</pos> <def>Sailing for pleasure in a yacht.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yachtman</ent><br/
<hw>Yacht"man</hw> <pr>(y<ocr/t"m<ait/n)</pr>, <pos>n.</pos> <def>See <er>Yachtsman</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yachtsman</ent><br/
<hw>Yachts"man</hw> <pr>(y<ocr/ts"m<ait/n)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Yachtsmen</plw> <pr>(y<ocr/ts"m<eit/n)</pr>.</plu> <def>One who owns or sails a yacht; a yachter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaf</ent><br/
<hw>Yaf</hw> <pr>(y<aum/f)</pr>, <mark>obs.</mark> <pos>imp.</pos> of <er>Give</er>. <ety>[AS. <ets>geaf</ets>, imp. of <ets>giefan</ets> to give.  See <er>Give</er>]</ety> <def>Gave.  See <er>Give</er>.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaffingale</ent><br/
<hw>Yaf"fin*gale</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Yaffle</er>, and cf. <er>Nightingale</er>.]</ety> <fld>(Zool.)</fld> <def>The yaffle.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaffle</ent><br/
<hw>Yaf"fle</hw> <pr>(y<acr/f"f'l)</pr>, <pos>n.</pos> <ety>[Probably imitative of its call or cry.]</ety> <fld>(Zool.)</fld> <def>The European green woodpecker (<spn>Picus viridis</spn> syn. <spn>Genius viridis</spn>).  It is noted for its loud laughlike note.  Called also <altname>eccle</altname>, <altname>hewhole</altname>, <altname>highhoe</altname>, <altname>laughing bird</altname>, <altname>popinjay</altname>, <altname>rain bird</altname>, <altname>yaffil</altname>, <altname>yaffler</altname>, <altname>yaffingale</altname>, <altname>yappingale</altname>, <altname>yackel</altname>, and <altname>woodhack</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yager</ent><br/
<hw>Ya"ger</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[G. <ets>j<aum/ger</ets> a hunter, from <ets>jagen</ets> to chase, hunt.]</ety> <fld>(Mil.)</fld> <def>In the German army, one belonging to a body of light infantry armed with rifles, resembling the <xex>chasseur</xex> of the French army.</def>  <altsp>[Written also <asp>jager</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaguarundi</ent><br/
<hw>Ya`gua*run"di</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same as <er>Jaguarondi</er>.</def>  <altsp>[Written also <asp>yaguarondi</asp>, and <asp>yagouarondi</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>yahoo</ent><br/
<hw>ya"hoo</hw> <pr>(y<aum/"h<oomac/)</pr>, <pos>n.</pos> <sn>1.</sn> <def>One of a race of filthy brutes resembling men but subject to the Houyhnhnms in Swift's <ldquo/Gulliver's Travels.<rdquo/  See in the Dictionary of Noted Names in Fiction.</def><br/
[<source>Webster 1913 Suppl.</source> + <source>WordNet 1.5</source> + <source>CM</source>]</p>

<p><sn>2.</sn>  <def>Hence, any brutish or vicious character.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn>  <def>A raw countryman; a lout; a greenhorn.</def> <mark>[U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>4.</sn> <def>Someone who is not very intelligent or not interested in culture.</def><br/
<syn><b>Syn. --</b> yokel, rube, hick, hayseed, bumpkin, chawbacon.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yahwe</ent><br/
<ent>Yahweh</ent><br/
<ent>Jahve</ent><br/
<ent>Jahveh</ent><br/
<mhw>{ <hw>Yah"weh</hw> <pr>(y<aum/"w<ecr/)</pr>, <hw>Yah"we</hw>, <pos>prop. n.</pos> Also <hw>Jah"veh</hw> <pr>(y<aum/"w<ecr/)</pr>, <hw>Jah"ve</hw>, <hw>Yahve</hw>, <hw>Yahveh</hw>, etc. }</mhw> <def>A modern transliteration of the Hebrew word translated <altname>Jehovah</altname> in the Bible; -- used by some critics to discriminate the tribal god of the ancient Hebrews from the Christian <ex>Jehovah</ex>.  <ex>Yahweh</ex> or <altname>Yahwe</altname> is the spelling now generally adopted by scholars.</def><br/
<syn><b>Syn. --</b> Yahwe, Yahveh, Wahvey, Jahve, Jahveh, Jahvey, Jahweh, Jehovah.</syn><br/
[<source>Webster 1913 Suppl.</source> <source>+WordNet 1.5</source> <source>+CM</source>]</p>

<p><ent>Yahwism</ent><br/
<ent>Jahvism</ent><br/
<mhw>{ <hw>Yah"wism</hw> <pr>(?)</pr>, <pos>n.</pos> Also <hw>Jah"vism</hw> <pr>(?)</pr> }</mhw>. <sn>1.</sn> <def>The religion or worship of <etsep>Yahweh</etsep> (Jehovah), or the system of doctrines, etc., connected with it.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>2.</sn>  <def>Use of <xex>Yahweh</xex> as a name of God.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yahwist</ent><br/
<ent>Jehovist</ent><br/
<ent>Jahwist</ent><br/
<ent>Jahvist</ent><br/
<mhw><hw>Yah"wist</hw> <pr>(?)</pr>, <pos>n.</pos> Also <hw>Jah"vist</hw> <pr>(<?/)</pr>, <hw>Jah"wist</hw>, older <hw>Je*ho"vist</hw>.</mhw> <def>The author of the passages of the Old Testament, esp. those of the Hexateuch, in which God is styled <xex>Yahweh</xex>, or <xex>Jehovah</xex>; the author of the Yahwistic, or Jehovistic, Prophetic Document (J); also, the document itself.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yajur-Veda</ent><br/
||<hw>Yaj"ur-Ve"da</hw> <pr>(y<adot/j"<ucir/r-v<amac/`d<adot/ <it>or</it> y<adot/j"<ucir/r-v<emac/`d<adot/)</pr>, <pos>n.</pos> <ety>[Skr. <ets>yajur-v<emac/da</ets>.]</ety> <def>See <er>Veda</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yak</ent><br/
<hw>Yak</hw> <pr>(y<acr/k)</pr>, <pos>n.</pos> <ety>[Tibetan <ets>gyag</ets>.]</ety> <fld>(Zool.)</fld> <def>A bovine mammal (<spn>Poephagus grunnies</spn>) native of the high plains of Central Asia. Its neck, the outer side of its legs, and its flanks, are covered with long, flowing, fine hair. Its tail is long and bushy, often white, and is valued as an ornament and for other purposes in India and China. There are several domesticated varieties, some of which lack the mane and the long hair on the flanks. Called also <altname>chauri gua</altname>, <altname>grunting cow</altname>, <altname>grunting ox</altname>, <altname>sarlac</altname>, <altname>sarlik</altname>, and <altname>sarluc</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yak lace</b></col>, <cd>a coarse pillow lace made from the silky hair of the yak.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yakamilk</ent><br/
<hw>Yak"a*milk</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See <er>Trumpeter</er>, 3 <sd>(a)</sd>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yakare</ent><br/
<hw>Yak"a*re`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same as <er>Yacare</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yakin</ent><br/
<hw>Ya"kin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A large Asiatic antelope (<spn>Budorcas taxicolor</spn>) native of the higher parts of the Himalayas and other lofty mountains. Its head and neck resemble those of the ox, and its tail is like that of the goat. Called also <altname>budorcas</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yakoots</ent><br/
<hw>Ya*koots"</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing. <singw>Yakoot</singw> <pr>(<?/)</pr></sing>.<def> <fld>(Ethnol.)</fld> A nomadic Mongolian tribe native of Northern Siberia, and supposed to be of Turkish stock. They are mainly pastoral in their habits.</def>  <altsp>[Written also <asp>Yakuts</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaksha</ent><br/
||<hw>Yak"sha</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr.]</ety> <fld>(Hindoo Myth.)</fld> <def>A kind of demigod attendant on Kuvera, the god of wealth.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yakut</ent><br/
<hw>Ya*kut"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The Turkish language of the Yakuts, a Mongolian people of northeastern Siberia, which is lingua franca over much of eastern Siberia.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yalah</ent><br/
<hw>Ya"lah</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The oil of the mahwa tree.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yalu</ent><br/
<hw>Ya"lu</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <def>A river in eastern Asia, which rises in North Korea and flows southwest to Korea Bay (forming part of the border between North Korea and China).</def><br/
<syn><b>Syn. --</b> Yalu River.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yam</ent><br/
<hw>Yam</hw> <pr>(y<acr/m)</pr>, <pos>n.</pos> <ety>[Pg. <ets>inhame</ets>, probably from some native name.]</ety> <sn>1.</sn> <fld>(Bot.)</fld> <def>A large, esculent, farinaceous tuber of various climbing plants of the genus <gen>Dioscorea</gen>; also, the plants themselves. Mostly natives of warm climates. The plants have netted-veined, petioled leaves, and pods with three broad wings. The commonest species is <spn>Dioscorea sativa</spn>, but several others are cultivated.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>Any one of several cultural varieties of the sweet potato.</def> <mark>[U. S.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Chinese yam</b></col>, <cd>a plant (<spn>Dioscorea Batatas</spn>) with a long and slender tuber, hardier than most of the other species.</cd> -- <col><b>Wild yam</b></col>. <sd>(a)</sd> <cd>A common plant (<spn>Dioscorea villosa</spn>) of the Eastern United States, having a hard and knotty rootstock.</cd> <sd>(b)</sd> <cd>An orchidaceous plant (<spn>Gastrodia sesamoides</spn>) of Australia and Tasmania.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yama</ent><br/
||<hw>Ya"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr. <ets>yama</ets> a twin.]</ety> <fld>(Hindoo Myth.)</fld> <def>The king of the infernal regions, corresponding to the Greek Pluto, and also the judge of departed souls. In later times he is more exclusively considered the dire judge of all, and the tormentor of the wicked. He is represented as of a green color, with red garments, having a crown on his head, his eyes inflamed, and sitting on a buffalo, with a club and noose in his hands.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yamen</ent><br/
<hw>Ya"men</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Chin. <ets>ya</ets> a civil or military court + <ets>men</ets> a gate.]</ety> <def>In China, the official headquarters or residence of a mandarin, including court rooms, offices, gardens, prisons, etc.; the place where the business of any public department is transcated.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yamma</ent><br/
<hw>Yam"ma</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Llama</er>.]</ety> <fld>(Zool.)</fld> <def>The llama.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yamp</ent><br/
<hw>Yamp</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>An umbelliferous plant (<spn>Carum Gairdneri</spn>); also, its small fleshy roots, which are eaten by the Indians from Idaho to California.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yang</ent><br/
<hw>Yang</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Of imitative origin.]</ety> <def>The cry of the wild goose; a honk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yang</ent><br/
<hw>Yang</hw>, <pos>v. i.</pos> <def>To make the cry of the wild goose.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>yang</ent><br/
<hw>yang</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chinese philosophy)</fld> <def>One of the two fundamental principles.  See <er>yin and yang</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Yangtze</ent><br/
<hw>Yang"tze</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <sn>1.</sn> <def>a major river of Asia, which flows into the East China Sea.</def><br/
<syn><b>Syn. --</b> Yangtze River.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yank</ent><br/
<hw>Yank</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Scot. <ets>yank</ets> a sudden and severe blow.]</ety> <def>A jerk or twitch.</def>  <mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yank</ent><br/
<hw>Yank</hw>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yanked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yanking</conjf>.]</vmorph> <def>To twitch; to jerk.</def>  <mark>[Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yank</ent><br/
<hw>Yank</hw>, <pos>n.</pos> <def>An abbreviation of <er>Yankee</er>.</def>  <mark>[Slang]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yankee</ent><br/
<hw>Yan"kee</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Commonly considered to be a corrupt pronunciation of the word <ets>English</ets>, or of the French word <ets>Anglais</ets>, by the native Indians of America. According to Thierry, a corruption of <ets>Jankin</ets>, a diminutive of <ets>John</ets>, and a nickname given to the English colonists of Connecticut by the Dutch settlers of New York. Dr. W. Gordon (<ldquo/Hist. of the Amer. War,<rdquo/ ed, 1789, vol. i., pp. 324, 325) says it was a favorite cant word in Cambridge, Mass., as early as 1713, and that it meant <ets>excellent</ets>; as, a <ets>yankee</ets> good horse, <ets>yankee</ets> good cider, etc.  Cf. Scot <ets>yankie</ets> a sharp, clever, and rather bold woman, and Prov. E. bow-<ets>yankees</ets> a kind of leggins worn by agricultural laborers.]</ety> <def>A nickname for a native or citizen of New England, especially one descended from old New England stock; by extension, an inhabitant of the Northern States as distinguished from a Southerner; also, applied sometimes by foreigners to any inhabitant of the United States.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>From meanness first this Portsmouth <qex>Yankey</qex> rose,<br/
And still to meanness all his conduct flows.</q> <rj><qau>Oppression, A poem by an American (Boston, 1765).</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yankee</ent><br/
<hw>Yan"kee</hw>, <pos>a.</pos> <def>Of or pertaining to a Yankee; characteristic of the Yankees.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The alertness of the <qex>Yankee</qex> aspect.</q> <rj><qau>Hawthorne.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yankee clover</b></col>. <fld>(Bot.)</fld> <cd>See <cref>Japan clover</cref>, under <er>Japan</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yankee-Doodle</ent><br/
<hw>Yan`kee-Doo"dle</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The name of a tune adopted popularly as one of the national airs of the United States.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Humorously, a Yankee.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We might have withheld our political noodles<br/
From knocking their heads against hot <qex>Yankee-Doodles</qex>.</q> <rj><qau>Moore.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yankeeism</ent><br/
<hw>Yan"kee*ism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Yankee idiom, word, custom, or the like.</def>  <rj><au>Lowell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaourt</ent><br/
||<hw>Yaourt</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Turk. <ets>yoghurt</ets>.]</ety> <def>A fermented drink, or milk beer, made by the Turks.</def><-- now usually yoghurt--><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yap</ent><br/
<hw>Yap</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Icel. <ets>gj<amac/lpa</ets>; akin to <ets>yelp</ets>.  Cf. <er>Yaup</er>.]</ety> <def>To bark; to yelp.</def>  <rj><au>L'Estrange.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yap</ent><br/
<hw>Yap</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A bark; a yelp.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yapock</ent><br/
<hw>Ya"pock</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <ety>[Probably from the river <ets>Oyapok</ets>, between French Guiana and Brazil.]</ety> <fld>(Zool.)</fld> <def>A South American aquatic opossum (<spn>Chironectes variegatus</spn>) found in Guiana and Brazil. Its hind feet are webbed, and its fore feet do not have an opposable thumb for climbing. Called also <altname>water opossum</altname>.</def>  <altsp>[Written also <asp>yapack</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1673 --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yapon</ent><br/
<hw>Ya"pon</hw> <pr>(?; 277)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>Same as <er>Yaupon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarage</ent><br/
<hw>Yar"age</hw> <pr>(?; 48)</pr>, <pos>n.</pos> <ety>[See <er>Yare</er>, <pos>a.</pos>]</ety> <fld>(Naut.)</fld> <def>The power of moving, or being managed, at sea; -- said with reference to a ship.</def>  <rj><au>Sir T. North.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yard</ent><br/
<hw>Yard</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>yerd</ets>, AS. <ets>gierd</ets>, <ets>gyrd</ets>, a rod, stick, a measure, a yard; akin to OFries. <ets>ierde</ets>, OS. <ets>gerda</ets>, D. <ets>garde</ets>, G. <ets>gerte</ets>, OHG. <ets>gartia</ets>, <ets>gerta</ets>, <ets>gart</ets>, Icel. <ets>gaddr</ets> a goad, sting, Goth. <ets>gazds</ets>, and probably to L. <ets>hasta</ets> a spear.  Cf. <er>Gad</er>, <pos>n.</pos>, <er>Gird</er>, <pos>n.</pos>, <er>Gride</er>, <pos>v. i.</pos>, <er>Hastate</er>.]</ety>  <sn>1.</sn> <def>A rod; a stick; a staff.</def>  <mark>[Obs.]</mark>  <rj><au>P. Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If men smote it with a <qex>yerde</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A branch; a twig.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>The bitter frosts with the sleet and rain<br/
Destroyed hath the green in every <qex>yerd</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A long piece of timber, as a rafter, etc.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A measure of length, equaling three feet, or thirty-six inches, being the standard of English and American measure.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>The penis.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <fld>(Naut.)</fld> <def>A long piece of timber, nearly cylindrical, tapering toward the ends, and designed to support and extend a square sail. A yard is usually hung by the center to the mast.  See <xex>Illust.</xex> of <er>Ship</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <fld>(Zool.)</fld> <def>A place where moose or deer herd together in winter for pasture, protection, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><mcol><col><b>Golden Yard</b></col>, <it>or</it> <col><b>Yard and Ell</b></col></mcol> <fld>(Astron.)</fld>, <cd>a popular name of the three stars in the belt of Orion.</cd> -- <col><b>Under yard</b></col> [<it>i. e.</it>, under the rod], <cd>under contract.</cd> <mark>[Obs.]</mark> <au>Chaucer.</au></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yard</ent><br/
<hw>Yard</hw>, <pos>n.</pos> <ety>[OE. <ets>yard</ets>, <ets>yerd</ets>, AS. <ets>geard</ets>; akin to OFries. <ets>garda</ets> garden, OS. <ets>gardo</ets> garden, <ets>gard</ets> yard, D. <ets>gaard</ets> garden, G. <ets>garten</ets>, OHG. <ets>garto</ets> garden, <ets>gari</ets> inclosure, Icel. <ets>gar<edh/r</ets> yard, house, Sw. <ets>g<aring/rd</ets>, Dan. <ets>gaard</ets>, Goth. <ets>gards</ets> a house, <ets>garda</ets> sheepfold, L. <ets>hortus</ets> garden, Gr. <grk>cho`rtos</grk> an inclosure.  Cf. <er>Court</er>, <er>Garden</er>, <er>Garth</er>, <er>Horticulture</er>, <er>Orchard</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>An inclosure; usually, a small inclosed place in front of, or around, a house or barn; <as>as, a court<ex>yard</ex>; a cow<ex>yard</ex>; a barn<ex>yard</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>yard</qex> . . . inclosed all about with sticks<br/
In which she had a cock, hight chanticleer.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>An inclosure within which any work or business is carried on; <as>as, a dock<ex>yard</ex>; a ship<ex>yard</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Liberty of the yard</b></col>, <cd>a liberty, granted to persons imprisoned for debt, of walking in the yard, or within any other limits prescribed by law, on their giving bond not to go beyond those limits.</cd> -- <col><b>Prison yard</b></col>, <cd>an inclosure about a prison, or attached to it.</cd> -- <col><b>Yard grass</b></col> <fld>(Bot.)</fld>, <cd>a low-growing grass (<spn>Eleusine Indica</spn>) having digitate spikes. It is common in dooryards, and like places, especially in the Southern United States. Called also <altname>crab grass</altname>.</cd> -- <col><b>Yard of land</b></col>. <cd>See <er>Yardland</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yard</ent><br/
<hw>Yard</hw>, <pos>v. t.</pos> <def>To confine (cattle) to the yard; to shut up, or keep, in a yard; <as>as, to <ex>yard</ex> cows</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>yardage</ent><br/
<hw>yar"dage</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>distance measured in yards.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yardarm</ent><br/
<hw>Yard"arm`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <fld>(Naut.)</fld> <def>Either half of a square-rigged vessel's yard{6}, from the center or mast to the end.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Ships are said to be <xex>yardarm and yardarm</xex> when so near as to touch, or interlock yards.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Naut.)</fld> <def>The portion of a yard{6} outboard of the slings, often called the <altname>outer quarter</altname>.</def><br/
[<source>RDH</source>]</p>

<p><note>   A yard{6} is considered to have four unequal quarters,  two quarters extending from the mast to the slings on each side, and two smaller outer quarters outboard of the slings.</note><br/
[<source>RDH</source>]</p>

<p><ent>Yardful</ent><br/
<hw>Yard"ful</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Yardfuls</plw> <pr>(<?/)</pr>.</plu> <def>As much as a yard will contain; enough to fill a yard.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>yardie</ent><br/
<hw>yar"die</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A member of an international gang of Jamaican criminals who sell drugs and violence.</def> <ldquo/A much publicized raid on a <ex>yardie</ex> stronghold had first been simulated at Riot City.<rdquo/<br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yardland</ent><br/
<hw>Yard"land`</hw> <pr>(y<aum/rd"l<acr/nd`)</pr>, <pos>n.</pos> <fld>(O. Eng. Law)</fld> <def>A measure of land of uncertain quantity, varying from fifteen to forty acres; a virgate.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>yardline</ent><br/
<hw>yard"line</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(football)</fld>  <def>Any of the lines parallel to the goal lines indicating distance from the goal line on a football the field; <as>as, the twenty-five <ex>yardline</ex></as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yardstick</ent><br/
<hw>Yard"stick`</hw> <pr>(y<aum/rd"st<icr/k`)</pr>, <pos>n.</pos> <def>A stick three feet, or a yard, in length, used as a measure of distance, cloth, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yardwand</ent><br/
<hw>Yard"wand`</hw> <pr>(y<aum/rd"w<ocr/nd`)</pr>, <pos>n.</pos> <def>A yardstick.</def>  <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>yare</ent><br/
<hw>yare</hw> <pr>(y<acir/r)</pr>, <pos>a.</pos> <ety>[OE. <ets>yare</ets>, <ets><yogh/aru</ets>, AS. <ets>gearu</ets>; akin to OS. <ets>garu</ets>, OHG. <ets>garo</ets>, G. <ets>gar</ets>, Icel. <ets>gerr</ets> perfect, <ets>g<oum/rva</ets> quite, G. <ets>gerben</ets> to tan, to curry, OHG. <ets>garawen</ets>, <ets>garwen</ets>, to make ready.  Cf. <er>Carouse</er>, <er>Garb</er> clothing, <er>Gear</er>, <pos>n.</pos>]</ety> <def>Ready; dexterous; eager; lively; quick to move.</def>  <mark>[Obs.]</mark> <ldquo/Be <xex>yare</xex> in thy preparation.<rdquo/  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The lesser [ship] will come and go, leave or take, and is <qex>yare</qex>; whereas the greater is slow.</q> <rj><qau>Sir W. Raleigh.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yare</ent><br/
<hw>Yare</hw>, <pos>adv.</pos> <def>Soon.</def>  <mark>[Obs.]</mark>  <rj><au>Cursor Mundi.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarely</ent><br/
<hw>Yare"ly</hw>, <pos>adv.</pos> <def>In a yare manner.</def>  <mark>[Obs.]</mark>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yark</ent><br/
<hw>Yark</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To yerk.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarke</ent><br/
<hw>Yar"ke</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same as <er>Saki</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarn</ent><br/
<hw>Yarn</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>yarn</ets>, <ets><yogh/arn</ets>, AS. <ets>gearn</ets>; akin to D. <ets>garen</ets>, G., OHG., Icel., Sw., & Dan. <ets>garn</ets>; of uncertain origin.  Cf. <er>Cord</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Spun wool; woolen thread; also, thread of other material, as of cotton, flax, hemp, or silk; material spun and prepared for use in weaving, knitting, manufacturing sewing thread, or the like.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Rope Making)</fld> <def>One of the threads of which the strands of a rope are composed.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A story told by a sailor for the amusement of his companions; a story or tale; <as>as, to spin a <ex>yarn</ex></as>.</def>  <mark>[Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarnen</ent><br/
<hw>Yarn"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made of yarn; consisting of yarn.</def>  <mark>[Obs.]</mark> <ldquo/A pair of <xex>yarnen</xex> stocks.<rdquo/  <rj><au>Turbervile.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarnut</ent><br/
<hw>Yar"nut`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>See <er>Yernut</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarr</ent><br/
<hw>Yarr</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE. <ets><yogh/arren</ets>.]</ety> <def>To growl or snarl as a dog.</def>  <mark>[Obs.]</mark>  <rj><au>Ainsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarrish</ent><br/
<hw>Yar"rish</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Prov. E. <ets>yar</ets> sour, <ets>yare</ets> brackish.]</ety> <def>Having a rough, dry taste.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarrow</ent><br/
<hw>Yar"row</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>yarowe</ets>, <ets>yarwe</ets>, <ets><yogh/arowe</ets>, AS. <ets>gearwe</ets>; akin to D. <ets>gerw</ets>, OHG. <ets>garwa</ets>, <ets>garawa</ets>, G. <ets>garbe</ets>, <ets>schafgarbe</ets>, and perhaps to E. <ets>yare</ets>.]</ety> <fld>(Bot.)</fld> <def>An American and European composite plant (<spn>Achillea Millefolium</spn>) with very finely dissected leaves and small white corymbed flowers. It has a strong, and somewhat aromatic, odor and taste, and is sometimes used in making beer, or is dried for smoking. Called also <altname>milfoil</altname>, and <altname>nosebleed</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yarwhip</ent><br/
<hw>Yar"whip`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[So called from its sharp cry uttered when taking wing.]</ety> <fld>(Zool.)</fld> <def>The European bar-tailed godwit; -- called also <altname>yardkeep</altname>, and <xex>yarwhelp</xex>.  See <er>Godwit</er>.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>yashmak</ent><br/
<hw>ya"shmak</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>the face veil worn by Muslim women.</def><br/
<syn><b>Syn. --</b> yashmac.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yataghan</ent><br/
<hw>Yat"a*ghan</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Turk. <ets>y<amac/t<amac/gh<amac/n</ets>.]</ety> <def>A long knife, or short saber, common among Mohammedan nations, usually having a double curve, sometimes nearly straight.</def>  <altsp>[Written also <asp>ataghan</asp>, <asp>attaghan</asp>.]</altsp>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yate</ent><br/
<hw>Yate</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A gate.  See 1st <er>Gate</er>.</def>  <mark>[Obs. or Prov. Eng.]</mark>  <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaud</ent><br/
<hw>Yaud</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Yawd</er>.</def>  <mark>[Prov. Eng. & Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaul</ent><br/
<hw>Yaul</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Naut.)</fld> <def>See <er>Yawl</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaulp</ent><br/
<hw>Yaulp</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To yaup.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaup</ent><br/
<hw>Yaup</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See <er>Yap</er>, and <er>Yelp</er>.]</ety> <def>To cry out like a child; to yelp.</def>  <mark>[Scot. & Colloq. U. S.]</mark> <altsp>[Written also <asp>yawp</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaup</ent><br/
<hw>Yaup</hw>, <pos>n.</pos> <ety>[Written also <ets>yawp</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A cry of distress, rage, or the like, as the cry of a sickly bird, or of a child in pain.</def>  <mark>[Scot. & Colloq. U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>The blue titmouse.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yauper</ent><br/
<hw>Yaup"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who, or that which, yaups.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaupon</ent><br/
<hw>Yau"pon</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A shrub (<spn>Ilex Cassine</spn>) of the Holly family, native from Virginia to Florida. The smooth elliptical leaves are used as a substitute for tea, and were formerly used in preparing the <prod>black drink</prod> of the Indians of North Carolina. Called also <altname>South-Sea tea</altname>.</def>  <altsp>[Written also <asp>yapon</asp>, <asp>youpon</asp>, and <asp>yupon</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yautia</ent><br/
<hw>Yau*ti"a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Native name in the Antilles.]</ety> <def>In Puerto Rico, any of several araceous plants or their starchy edible roots, which are cooked and eaten like yams or potatoes, as the taro.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yaw</ent><br/
<hw>Yaw</hw> <pr>(y<add/)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yawed</conjf> <pr>(y<add/d)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yawing</conjf>.]</vmorph> <ety>[Cf. <er>Yew</er>, <pos>v. i.</pos>]</ety> <def>To rise in blisters, breaking in white froth, as cane juice in the clarifiers in sugar works.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaw</ent><br/
<hw>Yaw</hw>, <pos>v. i. & t.</pos> <ety>[Cf. Prov. G. <ets>gagen</ets> to rock, <ets>gageln</ets> to totter, shake, Norw. <ets>gaga</ets> to bend backward, Icel. <ets>gagr</ets> bent back, <ets>gaga</ets> to throw the neck back.]</ety> <fld>(Naut.)</fld> <def>To steer wild, or out of the line of her course; to deviate from her course, as when struck by a heavy sea; -- said of a ship.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Just as he would lay the ship's course, all <qex>yawing</qex> being out of the question.</q> <rj><qau>Lowell.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaw</ent><br/
<hw>Yaw</hw>, <pos>n.</pos> <fld>(Naut.)</fld> <def>A movement of a vessel by which she temporarily alters her course; a deviation from a straight course in steering.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>yawd</ent><br/
<hw>yawd</hw> <pr>(y<add/d)</pr>, <pos>n.</pos> <ety>[Cf. Icel. <ets>jalda</ets> a mare, E. <ets>jade</ets> a nag.]</ety> <def>A jade; an old horse or mare.</def>  <altsp>[Written also <asp>yaud</asp>.]</altsp> <mark>[Prov. Eng. & Scot.]</mark>  <rj><au>Grose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>yawl</ent><br/
<hw>yawl</hw> <pr>(y<add/l)</pr>, <pos>n.</pos> <ety>[D. <ets>jol</ets>; akin to LG. & Dan. <ets>jolle</ets>, Sw. <ets>julle</ets>.  Cf. <er>Jolly-boat</er>.]</ety> <sn>1.</sn> <fld>(Naut.)</fld> <def>A small ship's boat, usually rowed by four or six oars.</def>  <altsp>[Written also <asp>yaul</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A fore-and-aft-rigged vessel with two masts, a mainmast carrying a mainsail and jibs, taller than the mizzenmast and stepped a little farther forward than in a <contr>sloop</contr>, and with the mizzenmast, or jiggermast far aft, usually placed aft of the water line or aft the rudder post.  The mizzenmast of a yawl is smaller, and set further aft, than that of a <contr>sloop</contr>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+RDH</source>]</p>

<p><ent>Yawl</ent><br/
<hw>Yawl</hw>, <pos>v. i.</pos> <ety>[OE. <ets><yogh/aulen</ets>, <ets><yogh/oulen</ets>, <ets>gaulen</ets>, <ets>goulen</ets>, Icel. <ets>gaula</ets> to low, bellow.  Cf. <er>Gowl</er>.]</ety> <def>To cry out like a dog or cat; to howl; to yell.</def>  <rj><au>Tennyson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>There howling Scyllas <qex>yawling</qex> round about.</q> <rj><qau>Fairfax.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yawl-rigged</ent><br/
<hw>Yawl"-rigged"</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Naut.)</fld> <def>Having two masts with fore-and-aft sails, but differing from a schooner in that the after mast is very small, and stepped as far aft as possible.  See <xex>Illustration</xex> in Appendix.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yawn</ent><br/
<hw>Yawn</hw> <pr>(y<add/n)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yawned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yawning</conjf>.]</vmorph> <ety>[OE. <ets>yanien</ets>, <ets><yogh/anien</ets>, <ets>ganien</ets>, <ets>gonien</ets>, AS. <ets>g<amac/nian</ets>; akin to <ets>ginian</ets> to yawn, <ets>g<imac/nan</ets> to yawn, open wide, G. <ets>g<aum/hnen</ets> to yawn, OHG. <ets>gin<emac/n</ets>, <ets>gein<omac/n</ets>, Icel. <ets>g<imac/na</ets> to yawn, <ets>gin</ets> the mouth, OSlav. <ets>zijati</ets> to yawn, L. <ets>hiare</ets> to gape, yawn; and perhaps to E. <ets>begin</ets>, cf. Gr. <grk>cheia`</grk> a hole. <root/47<it>b</it>.  Cf. <ets>Begin</ets>, <ets>Gin</ets> to begin, <er>Hiatus</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To open the mouth involuntarily through drowsiness, dullness, or fatigue; to gape; to oscitate.</def>  <ldquo/The lazy, <xex>yawning</xex> drone.<rdquo/  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>And while above he spends his breath,<br/
The <qex>yawning</qex> audience nod beneath.</q> <rj><qau>Trumbull.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To open wide; to gape, as if to allow the entrance or exit of anything.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>'t is now the very witching time of night,<br/
When churchyards <qex>yawn</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To open the mouth, or to gape, through surprise or bewilderment.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To be eager; to desire to swallow anything; to express desire by yawning; <as>as, to <ex>yawn</ex> for fat livings</as>.</def>  <ldquo/One long, <xex>yawning</xex> gaze.<rdquo/  <rj><au>Landor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yawn</ent><br/
<hw>Yawn</hw>, <pos>n.</pos> <sn>1.</sn> <def>An involuntary act, excited by drowsiness, etc., consisting of a deep and long inspiration following several successive attempts at inspiration, the mouth, fauces, etc., being wide open.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>One person yawning in company will produce a spontaneous <qex>yawn</qex> in all present.</q> <rj><qau>N. Chipman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of opening wide, or of gaping.</def>  <rj><au>Addison.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A chasm, mouth, or passageway.</def>  <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Now gape the graves, and trough their <qex>yawns</qex> let loose<br/
Imprisoned spirits.</q> <rj><qau>Marston.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yawningly</ent><br/
<hw>Yawn"ing*ly</hw>, <pos>adv.</pos> <def>In a yawning manner.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yawp</ent><br/
<hw>Yawp</hw> <pr>(?)</pr>, <pos>v. & n.</pos> <def>See <er>Yaup</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaws</ent><br/
<hw>Yaws</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[African <ets>yaw</ets> a raspberry.]</ety> <fld>(Med.)</fld> <def>A disease, occurring in the Antilles and in Africa, characterized by yellowish or reddish tumors, of a contagious character, which, in shape and appearance, often resemble currants, strawberries, or raspberries. There are several varieties of this disease, variously known as <stype>framboesia</stype>, <stype>pian</stype>, <stype>verrugas</stype>, and <stype>crab-yaws</stype>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yaw-weed</ent><br/
<hw>Yaw"-weed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A low, shrubby, rubiaceous plant (<spn>Morinda Royoc</spn>) growing along the seacoast of the West Indies. It has small, white, odorous flowers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yazoo Fraud</ent><br/
<hw>Yaz"oo Fraud</hw> <pr>(?)</pr>. <fld>(U. S. Hist.)</fld> <def>The grant by the State of Georgia, by Act of Jan. 7, 1795, of 35,000,000 acres of her western territory, for $500,000, to four companies known as the <col><b>Yazoo Companies</b></col> from the region granted ; -- commonly so called, the act being known as the <col><b>Yazoo Frauds Act</b></col>, because of alleged corruption of the legislature, every member but one being a shareholder in one or more of the companies. The act granting the land was repealed in 1796 by a new legislature, and the repealing provision was incorporated in the State constitution in 1798. In 1802 the territory was ceded to the United States. The claims of the purchasers, whom Georgia had refused to compensate, were sustained by the United States Supreme Court, which (1810) declared the repealing act of 1796 unconstitutional. Congress in 1814 ordered the lands sold and appropriated $5,000,000 to pay the claims.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ybe</ent><br/
<hw>Y*be"</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> of <er>Be</er>.  <def>Been.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ycleped</ent><br/
<hw>Y*cleped"</hw> <pr>(?)</pr>, <pos>p. p.</pos> <ety>[AS. <ets>geclipod</ets>, p. p. of <ets>clipian</ets>, <ets>cleopian</ets>, <ets>cliopian</ets>, to call.  See <er>Clepe</er>, and also the Note under <er>Y-</er>.]</ety> <def>Called; named; -- obsolete, except in archaic or humorous writings.</def>  <altsp>[Spelt also <asp>yclept</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><q>It is full fair to ben <qex>yclept</qex> madame.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But come, thou goddess fair and free.<br/
In heaven <qex>ycleped</qex> Euphrosyne.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those charming little missives <qex>ycleped</qex> valentines.</q> <rj><qau>Lamb.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Y current</ent><br/
<hw>Y current</hw>. <fld>(Elec.)</fld> <def>The current through one branch of the star arrangement of a three-phase circuit.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Ydo</ent><br/
<hw>Y*do"</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> of <er>Do</er>. <def>Done.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ydrad</ent><br/
<hw>Y*drad"</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> <mord>of <er>Dread</er>.</mord> <def>Dreaded.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Yet nothing did he dread, but ever was <qex>ydrad</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ye</ent><br/
<mhw>{<hw>Y<supr>e</supr></hw>, <hw>Ye</hw> <pr>(<th/<emac/)</pr>}</mhw>, <def>an old method of printing the article <xex>the</xex> (AS.  <ets><thorn/e</ets>), the <ldquo/y<rdquo/ being used in place of the Anglo-Saxon thorn (<thorn/). It is sometimes incorrectly pronounced <pr>y<emac/</pr>.  See <er>The</er>, and <er>Thorn</er>, <pos>n.</pos>, 4.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ye</ent><br/
<hw>Y"<eum/</hw> <pr>(<emac/"<eit/)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Y<eum/n</plw> <pr>(<emac/"<eit/n)</pr>.</plu> <def>An eye.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>From his <qex>y<eum/n</qex> ran the water down.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ye</ent><br/
<hw>Ye</hw> <pr>(y<emac/)</pr>, <pos>pron.</pos> <ety>[OE. <ets>ye</ets>, <ets><yogh/e</ets>, nom. pl., AS. <ets>ge</ets>, <ets>g<imac/</ets>; cf. OS. <ets>ge</ets>, <ets>g<imac/</ets>, OFries. <ets>g<imac/</ets>, <ets><imac/</ets>, D. <ets>gij</ets>, Dan. & Sw. <ets>i</ets>, Icel. <ets><emac/r</ets>, OHG. <ets>ir</ets>, G. <ets>ihr</ets>, Goth. <ets>jus</ets>, Lith. <ets>jus</ets>, Gr. <grk>"ymei^s</grk>, Skr. <ets>yuyam</ets>. <root/189.]</ety> <def>The plural of the pronoun of the second person in the nominative case.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Ye</qex> ben to me right welcome heartily.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>But <qex>ye</qex> are washed, but <qex>ye</qex> are sanctified.</q> <rj><qau>1 Cor. vi. 11.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This would cost you your life in case <qex>ye</qex> were a man.</q> <rj><qau>Udall.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In Old English <xex>ye</xex> was used only as a nominative, and <xex>you</xex> only as a dative or objective. In the 16th century, however, <xex>ye</xex> and <xex>you</xex> became confused and were often used interchangeably, both as nominatives and objectives, and <xex>you</xex> has now superseded <xex>ye</xex> except in solemn or poetic use.  See <er>You</er>, and also the first Note under <er>Thou</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Vain pomp and glory of this world, I hate <qex>ye</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>I come, kind gentlemen, strange news to tell <qex>ye</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ye</ent><br/
<hw>Ye</hw> <pr>(y<amac/)</pr>, <pos>adv.</pos> <ety>[See <er>Yea</er>.]</ety> <def>Yea; yes.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yea</ent><br/
<hw>Yea</hw> <pr>(y<amac/ <or/ y<emac/; 277)</pr>, <pos>adv.</pos> <ety>[OE. <ets>ye</ets>, <ets>ya</ets>, <ets><yogh/e</ets>, <ets><yogh/a</ets>, AS. <ets>ge<aacute/</ets>; akin to OFries. <ets>g<emac/</ets>, <ets>i<emac/</ets>, OS., D., OHG., G., Dan. & Sw. <ets>ja</ets>, Icel, <ets>j<amac/</ets>, Goth. <ets>ja</ets>, <ets>jai</ets>, and probably to Gr. <grk>"h^</grk> truly, verily. <root/188.  Cf. <er>Yes</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Yes; ay; a word expressing assent, or an affirmative, or an affirmative answer to a question, now superseded by <xex>yes</xex>.  See <er>Yes</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Let your communication be <qex>yea</qex>, <qex>yea</qex>; nay, nay.</q> <rj><qau>Matt. v. 37.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>More than this; not only so, but; -- used to mark the addition of a more specific or more emphatic clause.  Cf. <er>Nay</er>, <pos>adv.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I therein do rejoice, <qex>yea</qex>, and will rejoice.</q> <rj><qau>Phil. i. 18.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Yea</xex> sometimes introduces a clause, with the sense of <xex>indeed</xex>, <xex>verily</xex>, <xex>truly</xex>. <ldquo/<xex>Yea</xex>, hath God said, Ye shall not eat of every tree of the garden?<rdquo/</note>  <rj><au>Gen. iii. 1.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yea</ent><br/
<hw>Yea</hw>, <pos>n.</pos> <def>An affirmative vote; one who votes in the affirmative; <as>as, a vote by <ex>yeas</ex> and nays</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ In the Scriptures, <xex>yea</xex> is used as a sign of certainty or stability. <ldquo/All the promises of God in him are <xex>yea</xex>, and in him Amen.<rdquo/</note>  <rj><au>2 Cor. i. 20.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yead</ent><br/
<hw>Yead</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>Properly, a variant of the defective imperfect <xex>yode</xex>, but sometimes mistaken for a present.  See the Note under <er>Yede</er>.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Years <qex>yead</qex> away and faces fair deflower.</q> <rj><qau>Drant.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yean</ent><br/
<hw>Yean</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yeaned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yeaning</conjf>.]</vmorph> <ety>[AS. <ets>e<aacute/nian</ets>, or <ets>gee<aacute/nian</ets>; perhaps akin to E. <ets>ewe</ets>, or perhaps to L. <ets>agnus</ets>, Gr. <?/.  Cf. <er>Ean</er>.]</ety> <def>To bring forth young, as a goat or a sheep; to ean.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeanling</ent><br/
<hw>Yean"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Yean</ets> + <ets>-ling</ets>.  Cf. <er>Eanling</er>.]</ety> <def>A lamb or a kid; an eanling.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Year</ent><br/
<hw>Year</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets>yer</ets>, <ets>yeer</ets>, <ets><yogh/er</ets>, AS. <ets>ge<aacute/r</ets>; akin to OFries. <ets>i<?/r</ets>, <ets>g<?/r</ets>, D. <ets>jaar</ets>, OHG. <ets>j<amac/r</ets>, G. <ets>jahr</ets>, Icel. <ets><amac/r</ets>, Dan. <ets>aar</ets>, Sw. <ets><aring/r</ets>, Goth. <ets>j<?/r</ets>, Gr. <?/ a season of the year, springtime, a part of the day, an hour, <?/ a year, Zend <ets>y<amac/re</ets> year. <root/4, 279.  Cf. <er>Hour</er>, <er>Yore</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The time of the apparent revolution of the sun trough the ecliptic; the period occupied by the earth in making its revolution around the sun, called the <xex>astronomical year</xex>; also, a period more or less nearly agreeing with this, adopted by various nations as a measure of time, and called the <xex>civil year</xex>; <as>as, the common lunar <ex>year</ex> of 354 days, still in use among the Mohammedans; the <ex>year</ex> of 360 days, etc. In common usage, the year consists of 365 days, and every fourth year (called <ex>bissextile</ex>, or <ex>leap year</ex>) of 366 days, a day being added to February on that year, on account of the excess above 365 days (see <er>Bissextile</er>)</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of twenty <qex>year</qex> of age he was, I guess.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>civil</xex>, or <xex>legal</xex>, <xex>year</xex>, in England, formerly commenced on the 25th of March. This practice continued throughout the British dominions till the year 1752.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The time in which any planet completes a revolution about the sun; <as>as, the <ex>year</ex> of Jupiter or of Saturn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <pluf>pl.</pluf> <def>Age, or old age; <as>as, a man in <ex>years</ex></as>.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Anomalistic year</b></col>, <cd>the time of the earth's revolution from perihelion to perihelion again, which is 365 days, 6 hours, 13 minutes, and 48 seconds.</cd> -- <col><b>A year's mind</b></col> <fld>(Eccl.)</fld>, <cd>a commemoration of a deceased person, as by a Mass, a year after his death.  Cf. <cref>A month's mind</cref>, under <er>Month</er>.</cd> -- <col><b>Bissextile year</b></col>. <cd>See <er>Bissextile</er>.</cd> -- <col><b>Canicular year</b></col>. <cd>See under <er>Canicular</er>.</cd> -- <col><b>Civil year</b></col>, <cd>the year adopted by any nation for the computation of time.</cd> -- <col><b>Common lunar year</b></col>, <cd>the period of 12 lunar months, or 354 days.</cd> -- <col><b>Common year</b></col>, <cd>each year of 365 days, as distinguished from <xex>leap year</xex>.</cd> -- <mcol><col><b>Embolismic year</b></col>, <it>or</it> <col><b>Intercalary lunar year</b></col></mcol>, <cd>the period of 13 lunar months, or 384 days.</cd> -- <col><b>Fiscal year</b></col> <fld>(Com.)</fld>, <cd>the year by which accounts are reckoned, or the year between one annual time of settlement, or balancing of accounts, and another.</cd> -- <col><b>Great year</b></col>. <cd>See <cref>Platonic year</cref>, under <er>Platonic</er>.</cd> -- <mcol><col><b>Gregorian year</b></col>, <col><b>Julian year</b></col></mcol>. <cd>See under <er>Gregorian</er>, and <er>Julian</er>.</cd> -- <col><b>Leap year</b></col>. <cd>See <er>Leap year</er>, in the Vocabulary.</cd> -- <col><b>Lunar astronomical year</b></col>, <cd>the period of 12 lunar synodical months, or 354 days, 8 hours, 48 minutes, 36 seconds.</cd> -- <col><b>Lunisolar year</b></col>. <cd>See under <er>Lunisolar</er>.</cd> -- <col><b>Periodical year</b></col>. <cd>See <cref>Anomalistic year</cref>, above.</cd> -- <mcol><col><b>Platonic year</b></col>, <col><b>Sabbatical year</b></col></mcol>. <cd>See under <er>Platonic</er>, and <er>Sabbatical</er>.</cd> -- <col><b>Sidereal year</b></col>, <cd>the time in which the sun, departing from any fixed star, returns to the same. This is 365 days, 6 hours, 9 minutes, and 9.3 seconds.</cd> -- <col><b>Tropical year</b></col>. <cd>See under <er>Tropical</er>.</cd> -- <col><b>Year and a day</b></col> <fld>(O. Eng. Law)</fld>, <cd>a time to be allowed for an act or an event, in order that an entire year might be secured beyond all question.</cd> <au>Abbott.</au> -- <col><b>Year of grace</b></col>, <cd>any year of the Christian era; Anno Domini; <sc>A. D.</sc> or <sc>a. d.</sc></cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>year 2000 problem</ent><br/
<ent>year 2000 bug</ent><br/
<mhw><hw>year 2000 bug</hw>, <hw>year 2000 problem</hw></mhw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Computers)</fld> <def>an error in the coding of certain computer programs in which the year portion of dates was represented by only two decimal digits, assuming that the first two digits are <ldquo/19<rdquo/.  In such a program the the year 1975 is represented as <ldquo/75<rdquo/.  This was a common practise in computer programming even into the 1990's, as many programmers failed to consider that their programs would be used after the year 1999.  Thus, with such a program, a person born in 2000 would be considered as 101 years old in 2001; many different serious problems, as various as the programs, could be caused by such an error.</def>  <note>In 1998 many programs with the <ex>year 2000 bug</ex> were still not corrected, and it is not clear how many programs will retain the bug when the year 2000 arrives.  Tune in then.</note><br/
<syn><b>Syn. --</b> millemium bug, Y2K bug, Y2K problem.</syn>
[<source>PJC</source>]</p>

<p><ent>year 2000 compliant</ent><br/
<hw>year 2000 compliant</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Computers)</fld> <def>having dates fully and properly represented, and not susceptible to failure due to the <er>year 2000 bug</er>.</def><br/
<syn><b>Syn. --</b> date compliant.</syn>
[<source>PJC</source>]</p>

<p><ent>Yeara</ent><br/
<hw>Ye*a"ra</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>The California poison oak (<spn>Rhus diversiloba</spn>).  See under <er>Poison</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yearbook</ent><br/
<hw>Year"book`</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>A book published yearly; any annual report or summary of the statistics or facts of a year, designed to be used as a reference book; <as>as, the Congregational <ex>Yearbook</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Eng. Law)</fld> <def>A book containing annual reports of cases adjudged in the courts of England.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1674 --><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <xex>Yearbooks</xex> are the oldest English reports extant, beginning with the reign of Edward II., and ending with the reign of Henry VIII. They were published annually, and derive their name from that fact. They consist of eleven parts, or volumes, are written in Law French, and extend over nearly two hundred years. There are, however, several hiatuses, or chasms, in the series.</note>  <rj><au>Kent.</au>  <au>Bouvier.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeared</ent><br/
<hw>Yeared</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Containing years; having existed or continued many years; aged.</def>  <mark>[Obs.]</mark>  <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>year-end</ent><br/
<hw>year"-end</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>the end of a calendar year.</def> <illu>he had to unload the merchandise before the <ex>year-end</ex></illu><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>year-end</ent><br/
<hw>year"-end</hw> <pr>(?)</pr>, <pos>adj.</pos> <sn>1.</sn> <def>taking place at the close of a fiscal year.</def> <illu><ex>year-end</ex> audit</illu><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yearling</ent><br/
<hw>Year"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Year</ets> + <ets>-ling</ets>.]</ety> <def>An animal one year old, or in the second year of its age; -- applied chiefly to cattle, sheep, and horses.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yearling</ent><br/
<hw>Year"ling</hw>, <pos>a.</pos> <def>Being a year old.</def>  <ldquo/A <xex>yearling</xex> bullock to thy name small smoke.<rdquo/  <rj><au>Pope.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>year-long</ent><br/
<ent>yearlong</ent><br/
<hw>year"-long</hw> <hw>year"long</hw> <pr>(?)</pr>, <pos>adj.</pos> <sn>1.</sn>  <def>lasting through a year.</def> <illu>attending <ex>year-long</ex> courses</illu><br/
<syn><b>Syn. --</b> yearlong.</syn><br/
[<source>WordNet 1.5</source> + <source>CM</source>]</p>

<p><ent>Yearly</ent><br/
<hw>Year"ly</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[AS. <ets>ge<aacute/rlic</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Happening, accruing, or coming every year; annual; <as>as, a <ex>yearly</ex> income; a <ex>yearly</ex> feast</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Lasting a year; <as>as, a <ex>yearly</ex> plant</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Accomplished in a year; <as>as, the <ex>yearly</ex> circuit, or revolution, of the earth</as>.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yearly</ent><br/
<hw>Year"ly</hw>, <pos>adv.</pos> <ety>[AS. <ets>ge<aacute/rlice</ets>.]</ety> <def>Annually; once a year to year; <as>as, blessings <ex>yearly</ex> bestowed</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Yearly</qex> will I do this rite.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yearn</ent><br/
<hw>Yearn</hw> <pr>(y<etil/rn)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yearned</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yearning</conjf>.]</vmorph> <ety>[Also <ets>earn</ets>, <ets>ern</ets>; probably a corruption of OE. <ets>ermen</ets> to grieve, AS. <ets>ierman</ets>, <ets>yrman</ets>, or <ets>geierman</ets>, <ets>geyrman</ets>, fr. <ets>earm</ets> wretched, poor; akin to D. & G. <ets>arm</ets>, Icel. <ets>armr</ets>, Goth. <ets>arms</ets>. The <ets>y-</ets> in English is perhaps due to the AS. <ets>ge</ets> (see <er>Y-</er>).]</ety> <def>To pain; to grieve; to vex.</def>  <mark>[Obs.]</mark> <ldquo/She laments, sir, for it, that it would <xex>yearn</xex> your heart to see it.<rdquo/  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>It <qex>yearns</qex> me not if men my garments wear.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yearn</ent><br/
<hw>Yearn</hw>, <pos>v. i.</pos> <def>To be pained or distressed; to grieve; to mourn.</def>  <mark>[Obs.]</mark> <ldquo/Falstaff he is dead, and we must <xex>yearn</xex> therefore.<rdquo/  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yearn</ent><br/
<hw>Yearn</hw>, <pos>v. i. & t.</pos> <ety>[See <er>Yearnings</er>.]</ety> <def>To curdle, as milk.</def>  <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yearn</ent><br/
<hw>Yearn</hw>, <pos>v. i.</pos> <ety>[OE. <ets>yernen</ets>, <ets><yogh/ernen</ets>, <ets><yogh/eornen</ets>, AS. <ets>geornian</ets>, <ets>gyrnan</ets>, fr. <ets>georn</ets> desirous, eager; akin to OS. <ets>gern</ets> desirous, <ets>girnean</ets>, <ets>gernean</ets>, to desire, D. <ets>gaarne</ets> gladly, willingly, G. <ets>gern</ets>, OHG. <ets>gerno</ets>, adv., <ets>gern</ets>, a., G. <ets>gier</ets> greed, OHG. <ets>gir<imac/</ets> greed, <ets>ger</ets> desirous, <ets>ger<omac/n</ets> to desire, G. be<ets>gehren</ets>, Icel. <ets>girna</ets> to desire, <ets>gjarn</ets> eager, Goth. fa<iacute/hu<ets>ga<iacute/rns</ets> covetous, <ets>ga<iacute/rnjan</ets> to desire, and perhaps to Gr. <grk>chai`rein</grk> to rejoice, be glad, Skr. <ets>hary</ets> to desire, to like. <root/33.]</ety> <def>To be filled with longing desire; to be harassed or rendered uneasy with longing, or feeling the want of a thing; to strain with emotions of affection or tenderness; to long; to be eager.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Joseph made haste; for his bowels did <qex>yearn</qex> upon his brother; and he sought where to weep.</q> <rj><qau>Gen. xliii. 30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Your mother's heart <qex>yearns</qex> towards you.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yearnful</ent><br/
<hw>Yearn"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[OE. <ets><yogh/eornful</ets>, AS. <ets>geornfull</ets>.]</ety> <def>Desirous.</def>  <mark>[Obs.]</mark>  <rj><au>Ormulum. P. Fletcher.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>yearning</ent><br/
<hw>yearn"ing</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>prolonged unfulfilled desire or need.</def><br/
<syn><b>Syn. --</b> longing.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>yearning</ent><br/
<hw>yearn"ing</hw> <pr>(?)</pr>, <pos>adj.</pos> <sn>1.</sn>  <def>full of longing or unfulfilled desire.</def><br/
<syn><b>Syn. --</b> wistful.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yearningly</ent><br/
<hw>Yearn"ing*ly</hw>, <pos>adv.</pos> <def>With yearning.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yearnings</ent><br/
<hw>Yearn"ings</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <ety>[Cf. AS. <ets>geirnan</ets>, <ets>geyrnan</ets>, to rum.  See 4th <er>Earn</er>.]</ety> <def>The maws, or stomachs, of young calves, used as a rennet for curdling milk.</def>  <mark>[Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>year-old</ent><br/
<hw>year"-old</hw> <pr>(?)</pr>, <pos>adj.</pos> <sn>1.</sn> <def>having reached an age as specified; <as>as, a two-<ex>year-old</ex> toddler</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>year-round</ent><br/
<hw>year"-round</hw> <pr>(?)</pr>, <pos>adj.</pos> <sn>1.</sn> <def>operating or continuing throughout the year; <as>as, a <ex>year-round</ex> resort; a <ex>year-round</ex> job</as>.  Antonym of <ant>seasonal</ant>.</def><br/
<syn><b>Syn. --</b> year-around.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Year's purchase</ent><br/
<hw>Year's purchase</hw> <pr>(?)</pr>. <def>The amount that is yielded by the annual income of property; -- used in expressing the value of a thing in the number of years required for its income to yield its purchase price, in reckoning the amount to be paid for annuities, etc.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yearth</ent><br/
<hw>Yearth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The earth.</def>  <mark>[Obs.]</mark> <ldquo/Is my son dead or hurt or on the <xex>yerthe</xex> felled?<rdquo/  <rj><au>Ld. Berners.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeast</ent><br/
<hw>Yeast</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets><yogh/eest</ets>, <ets><yogh/est</ets>, AS. <ets>gist</ets>; akin to D. <ets>gest</ets>, <ets>gist</ets>, G. <ets>gischt</ets>, <ets>g<aum/scht</ets>, OHG. <ets>jesan</ets>, <ets>jerian</ets>, to ferment, G. <ets>gischen</ets>, <ets>g<aum/schen</ets>, <ets>g<aum/hren</ets>, Gr. <?/ boiled, <grk>zei^n</grk> to boil, Skr. <ets>yas</ets>. <root/111.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The foam, or troth (<xex>top yeast</xex>), or the sediment (<xex>bottom yeast</xex>), of beer or other in fermentation, which contains the yeast plant or its spores, and under certain conditions produces fermentation in saccharine or farinaceous substances; a preparation used for raising dough for bread or cakes, and making it light and puffy; barm; ferment.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Spume, or foam, of water.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They melt thy <qex>yeast</qex> of waves, which mar<br/
Alike the Armada's pride, or spoils of Trafalgar.</q> <rj><qau>Byron.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- 3. <def>A form of fungus which grows as individual rounded cells, rather than in a mycelium, and reproduces by budding; esp. members of the orders <ord>Endomycetales</ord> and <ord>Moniliales</ord>.  Some fungi may grow both as a yeast or as a mycelium, depending on the conditions of growth.</def>  --><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yeast cake</b></col>, <cd>a mealy cake impregnated with the live germs of the yeast plant, and used as a conveniently transportable substitute for yeast.</cd> -- <col><b>Yeast plant</b></col> <fld>(Bot.)</fld>, <cd>the vegetable organism, or fungus, of which beer yeast consists. The yeast plant is composed of simple cells, or granules, about one three-thousandth of an inch in diameter, often united into filaments which reproduce by budding, and under certain circumstances by the formation of spores. The name is extended to other ferments of the same genus.  See <er>Saccharomyces</er>.</cd> -- <col><b>Yeast powder</b></col>, <cd>a baling powder, -- used instead of yeast in leavening bread.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeast-bitten</ent><br/
<hw>Yeast"-bit`ten</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Brewing)</fld> <def>A term used of beer when the froth of the yeast has reentered the body of the beer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeastiness</ent><br/
<hw>Yeast"i*ness</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The quality or state of being yeasty, or frothy.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeasty</ent><br/
<hw>Yeast"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Frothy; foamy; spumy, like yeast.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yedding</ent><br/
<hw>Yed"ding</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>geddung</ets>, <ets>gidding</ets>, <ets>giedding</ets>, from <ets>gieddian</ets>, <ets>giddian</ets>, to sing, speak.]</ety> <def>The song of a minstrel; hence, any song.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yede</ent><br/
<hw>Yede</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>imp.</pos> <def>Went.  See <er>Yode</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All as he bade fulfilled was indeed<br/
This ilke servant anon right out <qex>yede</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Spenser and some later writers mistook this for a present of the defective imperfect <xex>yode</xex>. It is, however, only a variant of <xex>yode</xex>.  See <er>Yode</er>, and cf. <er>Yead</er>.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] on foot was forced for to <qex>yeed</qex>.</q> <rj><qau>Spenser</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeel</ent><br/
<hw>Yeel</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An eel.</def>  <mark>[Obs.]</mark>  <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeldhall</ent><br/
<hw>Yeld"hall`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Guildhall.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeldrine</ent><br/
<ent>Yeldrin</ent><br/
<mhw>{<hw>Yel"drin</hw> <pr>(?)</pr> <it>or</it> <hw>Yel"drine</hw>  }</mhw>, <pos>n.</pos> <ety>[Cf. <er>Yellow</er>.]</ety> <fld>(Zool.)</fld> <def>The yellow-hammer; -- called also <altname>yeldrock</altname>, and <altname>yoldrin</altname>.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yelk</ent><br/
<hw>Yelk</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as <er>Yolk</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yell</ent><br/
<hw>Yell</hw> <pr>(y<ecr/l)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yelled</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yelling</conjf>.]</vmorph> <ety>[OE. <ets>yellen</ets>, <ets><yogh/ellen</ets>, AS. <ets>giellan</ets>, <ets>gillan</ets>, <ets>gyllan</ets>; akin to D. <ets>gillen</ets>, OHG. <ets>gellan</ets>, G. <ets>gellen</ets>, Icel. <ets>gjalla</ets>, Sw. <ets>g<aum/lla</ets> to ring, resound, and to AS., OS., & OHG. <ets>galan</ets> to sing, Icel. <ets>gala</ets>.  Cf. 1st <er>Gale</er>, and <er>Nightingale</er>.]</ety> <def>To cry out, or shriek, with a hideous noise; to cry or scream as with agony or horror.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They <qex>yelleden</qex> as feendes doon in helle.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Nor the night raven, that still deadly <qex>yells</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Infernal ghosts and hellish furies round<br/
Environed thee; some howled, some <qex>yelled</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yell</ent><br/
<hw>Yell</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To utter or declare with a yell; to proclaim in a loud tone.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yell</ent><br/
<hw>Yell</hw>, <pos>n.</pos> <def>A sharp, loud, hideous outcry.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their hideous <qex>yells</qex><br/
Rend the dark welkin.</q> <rj><qau>J. Philips.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>yelling</ent><br/
<hw>yell"ing</hw> <pr>(?)</pr>, <pos>n.</pos>  <def>The uttering of one or more loud inarticulate cries, as of pain or excitement.</def><br/
<syn><b>Syn. --</b> shouting.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yellow</ent><br/
<hw>Yel"low</hw> <pr>(y<ecr/l"l<osl/)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos> <adjf>Yellower</adjf> <pr>(y<ecr/l"l<osl/*<etil/r)</pr>; <pos>superl.</pos> <adjf>Yellowest</adjf>.]</amorph> <ety>[OE. <ets>yelow</ets>, <ets>yelwe</ets>, <ets><yogh/elow</ets>, <ets><yogh/eoluw</ets>, from AS. <ets>geolu</ets>; akin to D. <ets>geel</ets>, OS. & OHG. <ets>gelo</ets>, G. <ets>gelb</ets>, Icel. <ets>gulr</ets>, Sw. <ets>gul</ets>, Dan. <ets>guul</ets>, L. <ets>helvus</ets> light bay, Gr. <grk>chlo`n</grk> young verdure, <grk>chlwro`s</grk> greenish yellow, Skr. <ets>hari</ets> tawny, yellowish. <root/49.  Cf. <er>Chlorine</er>, <er>Gall</er> a bitter liquid, <er>Gold</er>, <er>Yolk</er>.]</ety> <sn>1.</sn> <def>Being of a bright saffronlike color; of the color of gold or brass; having the hue of that part of the rainbow, or of the solar spectrum, which is between the orange and the green.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Her <qex>yellow</qex> hair was browded [braided] in a tress.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A sweaty reaper from his tillage brought<br/
First fruits, the green ear and the <qex>yellow</qex> sheaf.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The line of <qex>yellow</qex> light dies fast away.</q> <rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Cowardly; hence, dishonorable; mean; contemptible; <as>as, he has a <ex>yellow</ex> streak</as>.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><sn>3.</sn>  <def>Sensational; -- said of some newspapers, their makers, etc.; <as>as, <ex>yellow</ex> journal, journalism, etc.</as></def> <mark>[Colloq.]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Yellow atrophy</b></col> <fld>(Med.)</fld>, <cd>a fatal affection of the liver, in which it undergoes fatty degeneration, and becomes rapidly smaller and of a deep yellow tinge. The marked symptoms are black vomit, delirium, convulsions, coma, and jaundice.</cd> -- <col><b>Yellow bark</b></col>, <cd>calisaya bark.</cd> -- <col><b>Yellow bass</b></col> <fld>(Zool.)</fld>, <cd>a North American fresh-water bass (<spn>Morone interrupta</spn>) native of the lower parts of the Mississippi and its tributaries. It is yellow, with several more or less broken black stripes or bars. Called also <altname>barfish</altname>.</cd> -- <col><b>Yellow berry</b></col>. <fld>(Bot.)</fld> <cd>Same as <cref>Persian berry</cref>, under <er>Persian</er>.</cd> -- <col><b>Yellow boy</b></col>, <cd>a gold coin, as a guinea.</cd> <mark>[Slang]</mark> <au>Arbuthnot.</au> -- <col><b>Yellow brier</b></col>. <fld>(Bot.)</fld> <cd>See under <er>Brier</er>.</cd> -- <col><b>Yellow bugle</b></col> <fld>(Bot.)</fld>, <cd>a European labiate plant (<spn>Ajuga Chamaepitys</spn>).</cd> -- <col><b>Yellow bunting</b></col> <fld>(Zool.)</fld>, <cd>the European yellow-hammer.</cd> -- <col><b>Yellow cat</b></col> <fld>(Zool.)</fld>, <cd>a yellow catfish; especially, the bashaw.</cd> -- <col><b>Yellow copperas</b></col> <fld>(Min.)</fld>, <cd>a hydrous sulphate of iron; -- called also <altname>copiapite</altname>.</cd> -- <col><b>Yellow copper ore</b></col>, <cd>a sulphide of copper and iron; copper pyrites.  See <er>Chalcopyrite</er>.</cd> -- <col><b>Yellow cress</b></col> <fld>(Bot.)</fld>, <cd>a yellow-flowered, cruciferous plant (<spn>Barbarea praecox</spn>), sometimes grown as a salad plant.</cd> -- <col><b>Yellow dock</b></col>. <fld>(Bot.)</fld> <cd>See the Note under <er>Dock</er>.</cd> -- <col><b>Yellow earth</b></col>, <cd>a yellowish clay, colored by iron, sometimes used as a yellow pigment.</cd> -- <col><b>Yellow fever</b></col> <fld>(Med.)</fld>, <cd>a malignant, contagious, febrile disease of warm climates, attended with jaundice, producing a yellow color of the skin, and with the black vomit.  See <er>Black vomit</er>, in the Vocabulary.</cd> -- <col><b>Yellow flag</b></col>, <cd>the quarantine flag.  See under <er>Quarantine</er>, and 3d <er>Flag</er>.</cd> -- <col><b>Yellow jack</b></col>. <sd>(a)</sd> <cd>The yellow fever.  See under 2d <er>Jack</er>.</cd> <sd>(b)</sd> <cd>The quarantine flag.  See under <er>Quarantine</er>.</cd> -- <col><b>Yellow jacket</b></col> <fld>(Zool.)</fld>, <cd>any one of several species of American social wasps of the genus <gen>Vespa</gen>, in which the color of the body is partly bright yellow. These wasps are noted for their irritability, and for their painful stings.</cd> -- <col><b>Yellow lead ore</b></col> <fld>(Min.)</fld>, <cd>wulfenite.</cd> -- <col><b>Yellow lemur</b></col> <fld>(Zool.)</fld>, <cd>the kinkajou.</cd> -- <col><b>Yellow macauco</b></col> <fld>(Zool.)</fld>, <cd>the kinkajou.</cd> -- <col><b>Yellow mackerel</b></col> <fld>(Zool.)</fld>, <cd>the jurel.</cd> -- <col><b>Yellow metal</b></col>. <cd>Same as <cref>Muntz metal</cref>, under <er>Metal</er>.</cd> -- <col><b>Yellow ocher</b></col> <fld>(Min.)</fld>, <cd>an impure, earthy variety of brown iron ore, which is used as a pigment.</cd> -- <col><b>Yellow oxeye</b></col> <fld>(Bot.)</fld>, <cd>a yellow-flowered plant (<spn>Chrysanthemum segetum</spn>) closely related to the oxeye daisy.</cd> -- <col><b>Yellow perch</b></col> <fld>(Zool.)</fld>, <cd>the common American perch.  See <er>Perch</er>.</cd> -- <col><b>Yellow pike</b></col> <fld>(Zool.)</fld>, <cd>the wall-eye.</cd> -- <col><b>Yellow pine</b></col> <fld>(Bot.)</fld>, <cd>any of several kinds of pine; also, their yellowish and generally durable timber. Among the most common are valuable species are <spn>Pinus mitis</spn> and <spn>Pinus palustris</spn> of the Eastern and Southern States, and <spn>Pinus ponderosa</spn> and <spn>Pinus Arizonica</spn> of the Rocky Mountains and Pacific States.</cd> -- <col><b>Yellow plover</b></col> <fld>(Zool.)</fld>, <cd>the golden plover.</cd> -- <col><b>Yellow precipitate</b></col> <fld>(Med. Chem.)</fld>, <cd>an oxide of mercury which is thrown down as an amorphous yellow powder on adding corrosive sublimate to limewater.</cd> -- <col><b>Yellow puccoon</b></col>. <fld>(Bot.)</fld> <cd>Same as <er>Orangeroot</er>.</cd> -- <col><b>Yellow rail</b></col> <fld>(Zool.)</fld>, <cd>a small American rail (<spn>Porzana Noveboracensis</spn>) in which the lower parts are dull yellow, darkest on the breast. The back is streaked with brownish yellow and with black, and spotted with white. Called also <altname>yellow crake</altname>.</cd> -- <mcol><col><b>Yellow rattle</b></col>, <col><b>Yellow rocket</b></col></mcol>. <fld>(Bot.)</fld> <cd>See under <er>Rattle</er>, and <er>Rocket</er>.</cd> -- <col><b>Yellow Sally</b></col> <fld>(Zool.)</fld>, <cd>a greenish or yellowish European stone fly of the genus <gen>Chloroperla</gen>; -- so called by anglers.</cd> -- <col><b>Yellow sculpin</b></col> <fld>(Zool.)</fld>, <cd>the dragonet.</cd> -- <col><b>Yellow snake</b></col> <fld>(Zool.)</fld>, <cd>a West Indian boa (<spn>Chilobothrus inornatus</spn>) common in Jamaica. It becomes from eight to ten long. The body is yellowish or yellowish green, mixed with black, and anteriorly with black lines.</cd> -- <col><b>Yellow spot</b></col>. <sd>(a)</sd> <fld>(Anat.)</fld> <cd>A small yellowish spot with a central pit, the <xex>fovea centralis</xex>, in the center of the retina where vision is most accurate.  See <er>Eye</er>.</cd> <sd>(b)</sd> <fld>(Zool.)</fld> <cd>A small American butterfly (<spn>Polites Peckius</spn>) of the Skipper family. Its wings are brownish, with a large, irregular, bright yellow spot on each of the hind wings, most conspicuous beneath. Called also <altname>Peck's skipper</altname>. See <xex>Illust.</xex> under <er>Skipper</er>, <pos>n.</pos>, 5.</cd> -- <col><b>Yellow tit</b></col> <fld>(Zool.)</fld>, <cd>any one of several species of crested titmice of the genus <gen>Machlolophus</gen>, native of India. The predominating colors of the plumage are yellow and green.</cd> -- <col><b>Yellow viper</b></col> <fld>(Zool.)</fld>, <cd>the fer-de-lance.</cd> -- <col><b>Yellow warbler</b></col> <fld>(Zool.)</fld>, <cd>any one of several species of American warblers of the genus <gen>Dendroica</gen> in which the predominant color is yellow, especially <spn>Dendroica aestiva</spn>, which is a very abundant and familiar species; -- called also <altname>garden warbler</altname>, <altname>golden warbler</altname>, <altname>summer yellowbird</altname>, <altname>summer warbler</altname>, and <altname>yellow-poll warbler</altname>.</cd> -- <col><b>Yellow wash</b></col> <fld>(Pharm.)</fld>, <cd>yellow oxide of mercury suspended in water, -- a mixture prepared by adding corrosive sublimate to limewater.</cd> -- <col><b>Yellow wren</b></col> <fld>(Zool.)</fld> <sd>(a)</sd> <cd>The European willow warbler.</cd> <sd>(b)</sd> <cd>The European wood warbler.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellow</ent><br/
<hw>Yel"low</hw>, <pos>n.</pos> <sn>1.</sn> <def>A bright golden color, reflecting more light than any other except white; the color of that part of the spectrum which is between the orange and green.</def>  <ldquo/A long motley coat guarded with <xex>yellow</xex>.<rdquo/  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A yellow pigment.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Cadmium yellow</b></col>, <col><b>Chrome yellow</b></col>, <col><b>Indigo yellow</b></col>, <col><b>King's yellow</b></col>, etc.</mcol>  <cd>See under <er>Cadmium</er>, <er>Chrome</er>, etc.</cd> -- <col><b>Naples yellow</b></col>, <cd>a yellow amorphous pigment, used in oil, porcelain, and enamel painting, consisting of a basic lead metantimonate, obtained by fusing together tartar emetic lead nitrate, and common salt.</cd> -- <col><b>Patent yellow</b></col> <fld>(Old Chem.)</fld>, <cd>a yellow pigment consisting essentially of a lead oxychloride; -- called also <altname>Turner's yellow</altname>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellow</ent><br/
<hw>Yel"low</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yellowed</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yellowing</conjf>.]</vmorph> <def>To make yellow; to cause to have a yellow tinge or color; to dye yellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellow</ent><br/
<hw>Yel"low</hw>, <pos>v. i.</pos> <def>To become yellow or yellower.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowammer</ent><br/
<hw>Yel"low*am`mer</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See <er>Yellow-hammer</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowbill</ent><br/
<hw>Yel"low*bill`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The American scoter.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowbird</ent><br/
<hw>Yel"low*bird`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <sd>(a)</sd> <def>The American goldfinch, or thistle bird.  See <er>Goldfinch</er>.</def>  <sd>(b)</sd> <def>The common yellow warbler; -- called also <altname>summer yellowbird</altname>.  See <xex>Illust.</xex> of <cref>Yellow warbler</cref>, under <er>Yellow</er>, <pos>a.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellow Book</ent><br/
<hw>Yellow Book</hw>. <ety>[F. <ets>livre jaune</ets>.]</ety> <def>In France, an official government publication bound in yellow covers.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>yellow-brown</ent><br/
<hw>yel"low-brown`</hw> <pr>(?)</pr>, <pos>adj.</pos>  <def>Having a color intermediate between yellow and brown.</def><br/
<syn><b>Syn. --</b> amber, brownish-yellow.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yellow-covered</ent><br/
<hw>Yel"low-cov`ered</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Covered or bound in yellow paper.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yellow-covered literature</b></col>, <cd>cheap sensational novels and trashy magazines; -- formerly so called from the usual color of their covers.</cd> <mark>[Colloq. U. S.]</mark>  <rj><au>Bartlett.</au></rj>
</cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellow-eyed</ent><br/
<hw>Yel"low-eyed`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Having yellow eyes.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yellow-eyed grass</b></col> <fld>(Bot.)</fld>, <cd>any plant of the genus <gen>Xyris</gen>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowfin</ent><br/
<hw>Yel"low*fin`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A large squeteague.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowfish</ent><br/
<hw>Yel"low*fish`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A rock trout (<spn>Pleurogrammus monopterygius</spn>) found on the coast of Alaska; -- called also <altname>striped fish</altname>, and <altname>Atka mackerel</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellow-golds</ent><br/
<hw>Yel"low-golds`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A certain plant, probably the yellow oxeye.</def>  <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>yellow-green</ent><br/
<hw>yel"low-green`</hw> <pos>adj.</pos> <sn>1.</sn> <def>midway between yellow and green.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yellowhammer</ent><br/
<hw>Yel"low*ham`mer</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[For <ets>yellow-ammer</ets>, where <ets>ammer</ets> is fr. AS. <ets>amore</ets> a kind of bird; akin to G. <ets>ammer</ets> a yellow-hammer, OHG. <ets>amero</ets>.]</ety> <fld>(Zool.)</fld> <sd>(a)</sd> <def>A common European finch (<spn>Emberiza citrinella</spn>). The color of the male is bright yellow on the breast, neck, and sides of the head, with the back yellow and brown, and the top of the head and the tail quills blackish. Called also <altname>yellow bunting</altname>, <altname>scribbling lark</altname>, and <altname>writing lark</altname>.</def>  <altsp>[Written also <asp>yellow-ammer</asp>.]</altsp> <sd>(b)</sd> <def>The flicker.</def>  <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowing</ent><br/
<hw>Yel"low*ing</hw>, <pos>n.</pos> <def>The act or process of making yellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Softened . . . by the <qex>yellowing</qex> which time has given.</q> <rj><qau>G. Eliot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowish</ent><br/
<hw>Yel"low*ish</hw>, <pos>a.</pos> <def>Somewhat yellow; <as>as, amber is of a <ex>yellowish</ex> color</as>.</def>  -- <wordforms><wf>Yel"low*ish*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowlegs</ent><br/
<hw>Yel"low*legs`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Any one of several species of long-legged sandpipers of the genus <gen>Totanus</gen>, in which the legs are bright yellow; -- called also <altname>stone snipe</altname>, <altname>tattler</altname>, <altname>telltale</altname>, <altname>yellowshanks</altname>; and <altname>yellowshins</altname>.  See <er>Tattler</er>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowness</ent><br/
<hw>Yel"low*ness</hw>, <pos>n.</pos> <sn>1.</sn> <def>The quality or state of being yellow; <as>as, the <ex>yellowness</ex> of an orange</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Jealousy.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I will possess him with <qex>yellowness</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowroot</ent><br/
<hw>Yel"low*root`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>Any one of several plants with yellow roots.</def>  Specifically: <sd>(a)</sd> <def>See <er>Xanthorhiza</er>.</def>  <sd>(b)</sd> <def>Same as <er>Orangeroot</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellow pages</ent><br/
<hw>Yel"low pag`es</hw> <pr>(?)</pr>, <pos>n. pl.</pos> <def>a telephone book or part of a book in which the telephone numbers and often advertisements of business enterprises are listed in numerous sections, organized by the category of the business, the categories themselves being arranged alphabetically; a classified telephone directory.  So called because for many years the listing thus organized was printed on yellow paper, to distinguish it from the white pages containing the names of individuals, listed alphabetically by last name.  The yellow pages are usually bound together with the white pages in the telephone book distributed by the telephone company to its subscribers.  The name was adopted by companies not affiliated with the telephone company, for the classified business directories that they sell.</def><br/
[<source>PJC</source>]</p>

<p><ent>Yellows</ent><br/
<hw>Yel"lows</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <fld>(Far.)</fld> <def>A disease of the bile in horses, cattle, and sheep, causing yellowness of the eyes; jaundice.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>His horse . . . sped with spavins, rayed with the <qex>yellows</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Bot.)</fld> <def>A disease of plants, esp. of peach trees, in which the leaves turn to a yellowish color; jeterus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <fld>(Zool.)</fld> <def>A group of butterflies in which the predominating color is yellow. It includes the common small yellow butterflies.  Called also <altname>redhorns</altname>, and <altname>sulphurs</altname>.  See <er>Sulphur</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowseed</ent><br/
<hw>Yel"low*seed`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A kind of pepper grass (<spn>Lepidium campestre</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowshins</ent><br/
<ent>Yellowshanks</ent><br/
<mhw>{ <hw>Yel"low*shanks`</hw> <pr>(?)</pr>, <hw>Yel"low*shins`</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Zool.)</fld> <def>See <er>Yellolegs</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowtail</ent><br/
<hw>Yel"low*tail`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <sd>(a)</sd> <def>Any one of several species of marine carangoid fishes of the genus <gen>Seriola</gen>; especially, the large California species (<spn>Seriola dorsalis</spn>) which sometimes weighs thirty or forty pounds, and is highly esteemed as a food fish; -- called also <altname>cavasina</altname>, and <altname>white salmon</altname>.</def>  <sd>(b)</sd> <def>The mademoiselle, or silver perch.</def>  <sd>(c)</sd> <def>The menhaden.</def>  <sd>(d)</sd> <def>The runner, 12.</def>  <sd>(e)</sd> <def>A California rockfish (<spn>Sebastodes flavidus</spn>).</def>  <sd>(f)</sd> <def>The sailor's choice (<spn>Diplodus rhomboides</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Several other fishes are also locally called <xex>yellowtail</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowthroat</ent><br/
<hw>Yel"low*throat`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Any one of several species of American ground warblers of the genus <gen>Geothlypis</gen>, esp. the Maryland yellowthroat (<spn>Geothlypis trichas</spn>), which is a very common species.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowtop</ent><br/
<hw>Yel"low*top`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A kind of grass, perhaps a species of <gen>Agrostis</gen>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowwood</ent><br/
<hw>Yel"low*wood`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>The wood of any one of several different kinds of trees; also, any one of the trees themselves. Among the trees so called are the <spn>Cladrastis tinctoria</spn>, an American leguminous tree; the several species of prickly ash (<gen>Xanthoxylum</gen>); the Australian <spn>Flindersia Oxleyana</spn>, a tree related to the mahogany; certain South African species of <gen>Podocarpus</gen>, trees related to the yew; the East Indian <spn>Podocarpus latifolia</spn>; and the true satinwood (<spn>Chloroxylon Swietenia</spn>).  All these Old World trees furnish valuable timber.</def><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1675 --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yellowwort</ent><br/
<hw>Yel"low*wort`</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A European yellow-flowered, gentianaceous (<spn>Chlora perfoliata</spn>). The whole plant is intensely bitter, and is sometimes used as a tonic, and also in dyeing yellow.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yelp</ent><br/
<hw>Yelp</hw> <pr>(?)</pr>, <pos>v. i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yelped</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yelping</conjf>.]</vmorph> <ety>[OE. <ets>yelpen</ets>, <ets><yogh/elpen</ets>, to boast, boast noisily, AS. <ets>gielpan</ets>, <ets>gilpan</ets>, <ets>gylpan</ets>; akin to OHG. <ets>gelph</ets> arrogant: cf. Icel. <ets>gj<amac/lpa</ets> to yelp.  Cf. <er>Yap</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To boast.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>I keep [care] not of armes for to <qex>yelpe</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To utter a sharp, quick cry, as a hound; to bark shrilly with eagerness, pain, or fear; to yaup.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A little herd of England's timorous deer,<br/
Mazed with a <qex>yelping</qex> kennel of French curs?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>At the least flourish of a broomstick or ladle, he would fly to the door with a <qex>yelping</qex> precipitation.</q> <rj><qau>W. Irving.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yelp</ent><br/
<hw>Yelp</hw>, <pos>n.</pos> <def>A sharp, quick cry; a bark.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yelper</ent><br/
<hw>Yelp"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>An animal that yelps, or makes a yelping noise.</def>  Specifically: <fld>(Zool.)</fld> <sd>(a)</sd> <def>The avocet; -- so called from its sharp, shrill cry.</def>  <mark>[Prov. Eng.]</mark> <sd>(b)</sd> <def>The tattler.</def>  <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yelting</ent><br/
<hw>Yel"ting</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Orig. uncert.]</ety> <def>The Florida and West Indian red snapper (<spn>Lutianus aya</spn>); also, sometimes, one of certain other allied species, as <spn>Lutianus caxis</spn>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yeman</ent><br/
<hw>Ye"man</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A yeoman.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yemeni</ent><br/
<hw>Ye"me*ni</hw> <pr>(?)</pr>, <pos>prop. n.</pos>  <def>A native or inhabitant of <country>Yemen</country> .</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yemeni</ent><br/
<hw>Ye"me*ni</hw> <pr>(?)</pr>, <pos>prop. adj.</pos>  <def>Of or pertaining to <country>Yemen</country>; <as>as, <ex>Yemeni</ex> mountains</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><sn>2.</sn> <def>of or pertaining to the inhabitants of Yemen; <as>as, our <ex>Yemeni</ex> guide</as>.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yen</ent><br/
||<hw>Yen</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The unit of value and account in Japan. The <ex>yen</ex> is equal to 100 <xex>sen</xex>. From Japan's adoption of the gold standard, in 1897, to about 1913 the value of the yen was about 50 cents. In 1997 and 1998 the value of the yen varied from 80 per U. S. dollar to 120 per dollar.</def><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><ent>Yend</ent><br/
<hw>Yend</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To throw; to cast.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yenisei</ent><br/
<ent>Yenisey</ent><br/
<mhw><hw>Yenisei</hw>, <hw>Yenisey</hw></mhw> <pos>prop. n.</pos>  <def>A Russian river, flowing North into the Arctic Ocean.</def><br/
<syn><b>Syn. --</b> Yenisei, Yenisei River, Yenisey River.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yenite</ent><br/
<hw>Ye"nite</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[After <ets>Jena</ets>, in Germany.]</ety> <fld>(Min.)</fld> <def>A silicate of iron and lime occurring in black prismatic crystals; -- also called <altname>ilvaite</altname>.</def>  <altsp>[Spelt also <asp>jenite</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeoman</ent><br/
<hw>Yeo"man</hw> <pr>(?)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Yeomen</plw> <pr>(?)</pr>.</plu> <ety>[OE. <ets>yoman</ets>, <ets><yogh/eman</ets>, <ets><yogh/oman</ets>; of uncertain origin; perhaps the first, syllable is akin to OFries. <ets>g<amac/</ets> district, region, G. <ets>gau</ets>, OHG. <ets>gewi</ets>, <ets>gouwi</ets>, Goth. <ets>gawi</ets>. <root/100.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A common man, or one of the commonly of the first or most respectable class; a freeholder; a man free born.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ A <xex>yeoman</xex> in England is considered as next in order to the gentry. The word is little used in the United States, unless as a title in law proceedings and instruments, designating occupation, and this only in particular States.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A servant; a retainer.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>A <qex>yeman</qex> hadde he and servants no mo.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A yeoman of the guard; also, a member of the yeomanry cavalry.</def>  <mark>[Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <fld>(Naut.)</fld> <def>An interior officer under the boatswain, gunner, or carpenters, charged with the stowage, account, and distribution of the stores.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yeoman of the guard</b></col>, <cd>one of the bodyguard of the English sovereign, consisting of the hundred yeomen, armed with partisans, and habited in the costume of the sixteenth century. They are members of the royal household.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeomanlike</ent><br/
<hw>Yeo"man*like`</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Resembling, or suitable to, a yeoman; yeomanly.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeomanly</ent><br/
<hw>Yeo"man*ly</hw>, <pos>a.</pos> <def>Pertaining to a yeoman; becoming or suitable to, a yeoman; yeomanlike.</def>  <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Well could he dress his tackle <qex>yeomanly</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeomanry</ent><br/
<hw>Yeo"man*ry</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The position or rank of a yeoman.</def>  <mark>[Obs.]</mark> <ldquo/His estate of <xex>yeomanry</xex>.<rdquo/  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The collective body of yeomen, or freeholders.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The enfranchised <qex>yeomanry</qex> began to feel an instinct for dominion.</q> <rj><qau>Bancroft.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A British volunteer cavalry force, growing out of a royal regiment of fox hunters raised by Yorkshire gentlemen in 1745 to fight the Pretender, Charles Edward; -- calle dalso <altname>yeomanry cavalry</altname>. The members furnish their own horses, have fourteen days' annual camp training, and receive pay and allowance when on duty. In 1901 the name was altered to <altname>imperial yeomanry</altname> in recognition of the services of the force in the Boer war. See <er>Army organization</er>, above.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><col><b>Yeomanry cavalry</b></col>, <cd>certain bodies of volunteer cavalry liable to service in Great Britain only.</cd> <mark>[Eng.]</mark></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeorling</ent><br/
<hw>Yeor"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Yellow</er>.]</ety> <fld>(Zool.)</fld> <def>The European yellow-hammer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yer</ent><br/
<hw>Yer</hw> <pr>(?)</pr>, <pos>prep.</pos> <def>Ere; before.</def>  <mark>[Obs.]</mark>  <rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yerba</ent><br/
||<hw>Yer"ba</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Sp.]</ety> <fld>(Bot.)</fld> <def>An herb; a plant.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word is much used in compound names of plants in Spanish; as, <xex>yerba buena</xex> <ety>[Sp., a good herb]</ety>, a name applied in Spain to several kinds of mint (<spn>Mentha sativa</spn>, <spn>Mentha viridis</spn>, etc.), but in California universally applied to a common, sweet-scented labiate plant (<spn>Micromeria Douglasii</spn>).</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yerba dol osa</b></col>. <ety>[Sp., herb of the she-bear.]</ety> <cd>A kind of buckthorn (<spn>Rhamnus Californica</spn>).</cd> -- <col><b>Yerba mansa</b></col>. <ety>[Sp., a mild herb, soft herb.]</ety> <cd>A plant (<spn>Anemopsis Californica</spn>) with a pungent, aromatic rootstock, used medicinally by the Mexicans and the Indians.</cd> -- <col><b>Yerba reuma</b></col>. <ety>[Cf. Sp. <ets>reuma</ets> rheum, rheumatism.]</ety> <cd>A low California undershrub (<spn>Frankenia grandifolia</spn>).</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yerd</ent><br/
<hw>Yerd</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See 1st & 2d <er>Yard</er>.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yerk</ent><br/
<hw>Yerk</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yerked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yerking</conjf>.]</vmorph> <ety>[See <er>Yerk</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To throw or thrust with a sudden, smart movement; to kick or strike suddenly; to jerk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Their wounded steeds . . . <br/
<qex>Yerk</qex> out their armed heels at their dead masters.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To strike or lash with a whip.</def>  <mark>[Obs. or Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yerk</ent><br/
<hw>Yerk</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To throw out the heels; to kick; to jerk.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>They flirt, they <qex>yerk</qex>, they backward . . . fling.</q> <rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To move a quick, jerking motion.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yerk</ent><br/
<hw>Yerk</hw>, <pos>n.</pos> <def>A sudden or quick thrust or motion; a jerk.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yern</ent><br/
<hw>Yern</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See 3d <er>Yearn</er>.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yern</ent><br/
<hw>Yern</hw>, <pos>a.</pos> <ety>[OE. <ets><yogh/ern</ets>, <ets><yogh/eorne</ets>, AS. <ets>georn</ets> desirous, eager.  See <er>Yearn</er> to long.]</ety> <def>Eager; brisk; quick; active.</def>  <mark>[Obs.]</mark> <ldquo/Her song . . . loud and <xex>yern</xex>.<rdquo/  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yerne</ent><br/
<hw>Yerne</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[OE. <ets><yogh/eorne</ets>.  See <er>Yern</er>, <pos>a.</pos>]</ety> <def>Eagerly; briskly; quickly.</def>  <mark>[Obs.]</mark>  <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My hands and my tongue go so <qex>yerne</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yernut</ent><br/
<hw>Yer"nut`</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. Dan. <ets>jordn<oum/d</ets>, Sw. <ets>jordn<oum/t</ets>, earthnut.  Cf. <er>Jarnut</er>.]</ety> <def>An earthnut, or groundnut.  See <er>Groundnut</er> <sd>(d)</sd>.</def>  <altsp>[Written also <asp>yarnut</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yerst</ent><br/
<hw>Yerst</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>See <er>Erst</er>.</def>  <mark>[Obs.]</mark>  <rj><au>Sylvester.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yes</ent><br/
<hw>Yes</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[OE. <ets>yis</ets>, <ets><yogh/is</ets>, <ets><yogh/es</ets>, <ets><yogh/ise</ets>, AS. <ets>gese</ets>, <ets>gise</ets>; probably fr. <ets>ge<aacute/</ets> yea + <ets>sw<amac/</ets> so. <root/188.  See <er>Yea</er>, and <er>So</er>.]</ety> <def>Ay; yea; -- a word which expresses affirmation or consent; -- opposed to <ant>no</ant>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>Yes</xex> is used, like <xex>yea</xex>, to enforce, by repetition or addition, something which precedes; as, you have done all this -- <xex>yes</xex>, you have done more. <ldquo/<xex>Yes</xex>, you despise the man books confined.<rdquo/  <rj><au>Pope.</au></rj>
</note><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <ldquo/The fine distinction between <lsquo/yea' and <lsquo/yes,' <lsquo/nay' and <lsquo/no,' that once existed in English, has quite disappeared. <lsquo/Yea' and <lsquo/nay' in Wyclif's time, and a good deal later, were the answers to questions framed in the affirmative. <lsquo/Will he come?' To this it would have been replied, <lsquo/Yea' or <lsquo/Nay', as the case might be. But, <lsquo/Will he not come?' To this the answer would have been <lsquo/Yes' or <lsquo/No.'  Sir Thomas More finds fault with Tyndale, that in his translation of the Bible he had not observed this distinction, which was evidently therefore going out even then, that is, in the reign of Henry VIII.; and shortly after it was quite forgotten.<rdquo/</note>  <rj><au>Trench.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yest</ent><br/
<hw>Yest</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Yeast</er>.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yester</ent><br/
<hw>Yes"ter</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Yesterday</er>.]</ety> <def>Last; last past; next before; of or pertaining to yesterday.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[An enemy] whom <qex>yester</qex> sun beheld<br/
Mustering her charms.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ This word is now seldom used except in a few compounds; as, <xex>yester</xex>day, <xex>yester</xex>night, etc.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yesterday</ent><br/
<hw>Yes"ter*day</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[OE. <ets><yogh/isterdai</ets>, AS. <ets>geostran d<ae/g</ets>, from <ets>geostran</ets>, <ets>geostra</ets>, <ets>giestran</ets>, <ets>gistran</ets>, <ets>gystran</ets>, yesterday (akin to D. <ets>gisteren</ets>, G. <ets>gestern</ets>, OHG. <ets>gestaron</ets>, Icel. <ets>g<ae/r</ets> yesterday, to-morrow, Goth. <ets>gistradagis</ets> to-morrow, L. <ets>heri</ets> yesterday, Gr. <?/, Skr. <ets>hyas</ets>) + <ets>d<ae/g</ets> day.  Cf. <er>Hestern</er>. <?/<?/<?/<?/.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The day last past; the day next before the present.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>All our <qex>yesterdays</qex> have lighted fools<br/
The way to dusty death.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>We are but of <qex>yesterday</qex>, and know nothing.</q> <rj><qau>Job viii. 9.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Fig.: A recent time; time not long past.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>The proudest royal houses are but of <qex>yesterday</qex>, when compared with the line of supreme pontiffs.</q> <rj><qau>Macaulay.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yesterday</ent><br/
<hw>Yes"ter*day</hw>, <pos>adv.</pos> <def>On the day last past; on the day preceding to-day; <as>as, the affair took place <ex>yesterday</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yester-evening</ent><br/
<ent>Yestereve</ent><br/
<mhw>{ <hw>Yes"ter*eve`</hw> <pr>(?)</pr>, <hw>Yes"ter-e`ven*ing</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <def>The evening of yesterday; the evening last past.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yester-morning</ent><br/
<ent>Yestermorn</ent><br/
<mhw>{ <hw>Yes"ter*morn`</hw> <pr>(?)</pr>, <hw>Yes"ter-morn`ing</hw>, }</mhw> <pos>n.</pos> <def>The morning of yesterday.</def>  <rj><au>Coleridge.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yestern</ent><br/
<hw>Yes"tern</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Yester</er>.]</ety> <def>Of or pertaining to yesterday; relating to the day last past.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yesternight</ent><br/
<hw>Yes"ter*night`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The last night; the night last past.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yesternight</ent><br/
<hw>Yes"ter*night`</hw>, <pos>adv.</pos> <ety>[AS. <ets>gystran niht</ets>.  See <er>Yesterday</er>.]</ety> <def>On the last night.</def>  <rj><au>B. Jonson.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yesternoon</ent><br/
<hw>Yes"ter*noon`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The noon of yesterday; the noon last past.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yesterweek</ent><br/
<hw>Yes"ter*week`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The week last past; last week.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yesteryear</ent><br/
<hw>Yes"ter*year`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>The year last past; last year.</def>
<-- now also used to mean in olden days, not just last year. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yestreen</ent><br/
<hw>Yes`treen"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Yester-evening; yesternight; last night.</def>  <mark>[R. or Scot.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Yestreen</qex> I did not know<br/
How largely I could live.</q> <rj><qau>Bp. Coxe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yesty</ent><br/
<hw>Yest"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>See <er>Yeasty</er>.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yet</ent><br/
<hw>Yet</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Any one of several species of large marine gastropods belonging to the genus <gen>Yetus</gen>, or <gen>Cymba</gen>; a boat shell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yet</ent><br/
<hw>Yet</hw>, <pos>adv.</pos> <ety>[OE. <ets>yet</ets>, <ets><yogh/et</ets>, <ets><yogh/it</ets>, AS. <ets>git</ets>, <ets>gyt</ets>, <ets>giet</ets>, <ets>gieta</ets>; akin to OFries. <ets>ieta</ets>, <ets>eta</ets>, <ets>ita</ets>, MHG. <ets>iezuo</ets>, <ets>ieze</ets>, now, G. <ets>jetzo</ets>, <ets>jetzt</ets>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>In addition; further; besides; over and above; still.</def>  <ldquo/A little longer; <xex>yet</xex> a little longer.<rdquo/  <rj><au>Dryden.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This furnishes us with <qex>yet</qex> one more reason why our savior, lays such a particular stress acts of mercy.</q> <rj><qau>Atterbury.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The rapine is made <qex>yet</qex> blacker by the pretense of piety and justice.</q> <rj><qau>L'Estrange.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>At the same time; by continuance from a former state; still.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Facts they had heard while they were <qex>yet</qex> heathens.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Up to the present time; thus far; hitherto; until now; -- and with the negative, <xex>not yet</xex>, not up to the present time; not as soon as now; <as>as, Is it time to go? Not <ex>yet</ex></as>.  See <cref>As yet</cref>, under <er>As</er>, <pos>conj.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ne never <qex>yet</qex> no villainy ne said.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Before some future time; before the end; eventually; in time.</def>  <ldquo/He 'll be hanged <xex>yet</xex>.<rdquo/  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Even; -- used emphatically.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Men may not too rashly believe the confessions of witches, nor <qex>yet</qex> the evidence against them.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yet</ent><br/
<hw>Yet</hw> <pr>(?)</pr>, <pos>conj.</pos> <def>Nevertheless; notwithstanding; however.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Yet</qex> I say unto you, That even Solomon in all his glory was not arrayed like one of these.</q> <rj><qau>Matt. vi. 29.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- See <er>However</er>.</syn><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeve</ent><br/
<hw>Yeve</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To give.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yeven</ent><br/
<hw>Yev"en</hw> <pr>(?)</pr>, <pos>p. p.</pos> <def>Given.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yew</ent><br/
<hw>Yew</hw> <pr>(<umac/)</pr>, <pos>v. i.</pos> <def>See <er>Yaw</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yew</ent><br/
<hw>Yew</hw>, <pos>n.</pos> <ety>[OE. <ets>ew</ets>, AS. <ets>e<oacute/w</ets>, <ets><imac/w</ets>, <ets>eoh</ets>; akin to D. <ets>ijf</ets>, OHG. <ets><imac/wa</ets>, <ets><imac/ha</ets>, G. <ets>eibe</ets>, Icel. <ets><ymac/r</ets>; cf. Ir. <ets>iubhar</ets>, Gael. <ets>iubhar</ets>, <ets>iughar</ets>, W. <ets>yw</ets>, <ets>ywen</ets>, Lith. <ets>j<eum/va</ets> the black alder tree.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <fld>(Bot.)</fld> <def>An evergreen tree (<spn>Taxus baccata</spn>) of Europe, allied to the pines, but having a peculiar berrylike fruit instead of a cone. It frequently grows in British churchyards.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The wood of the yew.  It is light red in color, compact, fine-grained, and very elastic.  It is preferred to all other kinds of wood for bows and whipstocks, the best for these purposes coming from Spain.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The <stype>American yew</stype> (<spn>Taxus baccata</spn>, var. <varn>Canadensis</varn>) is a low and straggling or prostrate bush, never forming an erect trunk.  The <stype>California yew</stype> (<spn>Taxus brevifolia</spn>, also called <stype>Pacific yew</stype>) is a good-sized tree, and its wood is used for bows, spear handles, paddles, and other similar implements; the anticancer agent <prod>taxol</prod> is obtained from its bark.  Another yew is found in Florida, and there are species in Japan and the Himalayas.</note><br/
[<source>1913 Webster</source> + <source>PJC</source>]</p>

<p><sn>3.</sn> <def>A bow for shooting, made of the yew.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yew</ent><br/
<hw>Yew</hw> <pr>(<umac/)</pr>, <pos>a.</pos> <def>Of or pertaining to yew trees; made of the wood of a yew tree; <as>as, a <ex>yew</ex> whipstock</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yewen</ent><br/
<hw>Yew"en</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Made of yew; <as>as, <ex>yewen</ex> bows</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yex</ent><br/
<hw>Yex</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[OE. <ets><yogh/exen</ets>, <ets>yesken</ets>, AS. <ets>giscian</ets> to sob.]</ety> <def>To hiccough.</def>  <altsp>[Written also <asp>yox</asp>, <asp>yux</asp>.]</altsp> <mark>[Obs. or Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>He <qex>yexeth</qex> and he speaketh through the nose.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yex</ent><br/
<hw>Yex</hw>, <pos>n.</pos> <ety>[AS. <ets>geocsa</ets> a sobbing, hiccough.  Cf. <er>Yex</er>, <pos>v. i.</pos>]</ety> <def>A hiccough.</def>  <altsp>[Written also <asp>yox</asp>, and <asp>yux</asp>.]</altsp> <mark>[Obs. or Prov. Eng.]</mark> <ldquo/The excessive <xex>yex</xex>.<rdquo/  <rj><au>Holland.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yezdegerdian</ent><br/
<hw>Yez`de*ger"di*an</hw> <pr>(?; 277)</pr>, <pos>a.</pos> <def>Of or pertaining to <ets>Yezdegerd</ets>, the last Sassanian monarch of Persia, who was overthrown by the Muslims; <as>as, the <ex>Yezdegerdian</ex> era, which began on the 16th of June, <sc>a. d.</sc> 632. The era is still used by the Parsees</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yezdi</ent><br/
<hw>Yez"di</hw> <pr>(y<ecr/z"d<emac/)</pr>, <pos>n.</pos> <def>Same as <er>Izedi</er>.</def>  <rj><au>Tylor.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yezidi</ent><br/
<ent>Yezidee</ent><br/
<mhw>{ <hw>Yez"i*dee</hw> <pr>(?)</pr>, <hw>Yez"i*di</hw> <pr>(?)</pr> }</mhw>, <pos>n.</pos> <def>Same as <er>Izedi.</er></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yfere</ent><br/
<hw>Y*fere"</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Together.  See <er>Ifere</er>.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As friends do when they be met <qex>yfere</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ygdrasyl</ent><br/
<hw>Yg"dra*syl</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Scand. Myth.)</fld> <def>See in the Dictionary of Noted Names in Fiction.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yghe</ent><br/
<hw>Y"ghe</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Eye.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ygo</ent><br/
<hw>Y*go"</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> of <er>Go</er>. <def>Gone.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yground</ent><br/
<hw>Y*ground"</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos> of <er>Grind</er>.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yholde</ent><br/
<hw>Y*hold"e</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos> of <er>Hold</er>.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yid</ent><br/
<hw>Yid</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Yiddish</er>.]</ety> <def>A Jew; -- now (1998) usually considered offensive or contemptuous.</def> <mark>[Slang or Colloq.]</mark> <ldquo/Almost any young <xex>Yid</xex> who goes out from among her people.<rdquo/  <rj><au>John Corbin.</au></rj><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yiddish</ent><br/
<hw>Yid"dish</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[G. <ets>j<uum/disch</ets>, prop., Jewish, fr. <ets>Jude</ets> Jew. See <er>Jew</er>, <er>Jewish</er>.]</ety> <def>A language used by German and other Jews, being a Middle German dialect developed under Hebrew and Slavic influence. It is written in Hebrew characters.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yiddisher</ent><br/
<hw>Yid"dish*er</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Yiddish</er>.]</ety> <def>A Yid.</def> <mark>[Slang]</mark><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yield</ent><br/
<hw>Yield</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yielded</conjf>; <pos>obs. p. p.</pos> <conjf>Yold</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yielding</conjf>.]</vmorph> <ety>[OE. <ets>yelden</ets>, <ets><yogh/elden</ets>, <ets><yogh/ilden</ets>, AS. <ets>gieldan</ets>, <ets>gildan</ets>, to pay, give, restore, make an offering; akin to OFries. <ets>jelda</ets>, OS. <ets>geldan</ets>, D. <ets>gelden</ets> to cost, to be worth, G. <ets>gelten</ets>, OHG. <ets>geltan</ets> to pay, restore, make an offering, be worth, Icel. <ets>gjalda</ets> to pay, give up, Dan. <ets>gielde</ets> to be worth, Sw. <ets>g<aum/lla</ets> to be worth, <ets>g<aum/lda</ets> to pay, Goth. <ets>gildan</ets> in fra<ets>gildan</ets>, us<ets>gildan</ets>.  Cf. 1st <er>Geld</er>, <er>Guild</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To give in return for labor expended; to produce, as payment or interest on what is expended or invested; to pay; <as>as, money at interest <ex>yields</ex> six or seven per cent</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>To <qex>yelde</qex> Jesu Christ his proper rent.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>When thou tillest the ground, it shall not henceforth <qex>yield</qex> unto thee her strength.</q> <rj><qau>Gen. iv. 12.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To furnish; to afford; to render; to give forth.</def>  <ldquo/Vines <xex>yield</xex> nectar.<rdquo/  <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>[He] makes milch kine <qex>yield</qex> blood.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The wilderness <qex>yieldeth</qex> food for them and for their children.</q> <rj><qau>Job xxiv. 5.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To give up, as something that is claimed or demanded; to make over to one who has a claim or right; to resign; to surrender; to relinquish; as a city, an opinion, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And, force perforce, I'll make him <qex>yield</qex> the crown.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Shall <qex>yield</qex> up all their virtue, all their fame.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To admit to be true; to concede; to allow.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I <qex>yield</qex> it just, said Adam, and submit.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>To permit; to grant; <as>as, to <ex>yield</ex> passage</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>To give a reward to; to bless.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Tend me to-night two hours, I ask no more,<br/
And the gods <qex>yield</qex> you for 't.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>God <qex>yield</qex> thee, and God thank ye.</q> <rj><qau>Beau. & Fl.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>To yield the breath</b></col>, <col><b>To yield the breath up</b></col>, <col><b>To yield the ghost</b></col>, <col><b>To yield the ghost up</b></col>, <col><b>To yield up the ghost</b></col>, <it>or</it> <col><b>To yield the life</b></col></mcol>, <cd>to die; to expire; -- similar to <cref>To give up the ghost</cref>.</cd><br/
[<source>1913 Webster</source>]</p>

<p><q>One calmly <qex>yields</qex> his willing <qex>breath</qex>.</q> <rj><qau>Keble.</qau></rj>
</cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yield</ent><br/
<hw>Yield</hw>, <pos>v. i.</pos> <sn>1.</sn> <def>To give up the contest; to submit; to surrender; to succumb.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He saw the fainting Grecians <qex>yield</qex>.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To comply with; to assent; <as>as, I <ex>yielded</ex> to his request</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To give way; to cease opposition; to be no longer a hindrance or an obstacle; <as>as, men readily <ex>yield</ex> to the current of opinion, or to customs; the door <ex>yielded</ex>.</as></def><br/
[<source>1913 Webster</source>]</p>

<p><q>Will ye relent,<br/
And <qex>yield</qex> to mercy while 't is offered you?</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>To give place, as inferior in rank or excellence; <as>as, they will <ex>yield</ex> to us in nothing</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Nay tell me first, in what more happy fields<br/
The thistle springs, to which the lily <qex>yields</qex>?</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yield</ent><br/
<hw>Yield</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Amount yielded; product; -- applied especially to products resulting from growth or cultivation.</def>  <ldquo/A goodly <xex>yield</xex> of fruit doth bring.<rdquo/  <rj><au>Bacon.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yieldable</ent><br/
<hw>Yield"a*ble</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Disposed to yield or comply.</def> <mark>[R.]</mark> -- <wordforms><wf>Yield"a*ble*ness</wf>, <pos>n.</pos> <mark>[R.]</mark></wordforms>  <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yieldance</ent><br/
<hw>Yield"ance</hw> <pr>(?)</pr>, <pos>n.</pos> <sn>1.</sn> <def>The act of producing; yield; <as>as, the <ex>yieldance</ex> of the earth</as>.</def>  <mark>[R.]</mark>  <rj><au>Bp. Hall.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The act of yielding; concession.</def>  <mark>[R.]</mark>  <rj><au>South.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yielder</ent><br/
<hw>Yield"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who yields.</def>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yielding</ent><br/
<hw>Yield"ing</hw>, <pos>a.</pos> <def>Inclined to give way, or comply; flexible; compliant; accommodating; <as>as, a <ex>yielding</ex> temper</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yielding and paying</b></col> <fld>(Law)</fld>, <cd>the initial words of that clause in leases in which the rent to be paid by the lessee is mentioned and reserved.</cd>  <rj><au>Burrill.</au></rj>
</cs><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Obsequious; attentive.</syn> <usage> -- <er>Yielding</er>, <er>Obsequious</er>, <er>Attentive</er>. In many cases a man may be <xex>attentive</xex> or <xex>yielding</xex> in a high degree without any sacrifice of his dignity; but he who is <xex>obsequious</xex> seeks to gain favor by excessive and mean compliances for some selfish end.</usage><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Yield"ing*ly</wf>, <pos>adv.</pos> -- <wf>Yield"ing*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yieldless</ent><br/
<hw>Yield"less</hw>, <pos>a.</pos> <def>Without yielding; unyielding.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yift</ent><br/
<hw>Yift</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Gift.</def>  <mark>[Obs.]</mark> <ldquo/Great <xex>yiftes</xex>.<rdquo/  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yin</ent><br/
<hw>Yin</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A Chinese weight of 2<frac23/ pounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yin</ent><br/
<hw>Yin</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chinese philosophy)</fld> <def>one of the two fundamental principles.  See <er>yin and yang</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>yin and yang</ent><br/
<hw>yin and yang</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Chinese philosophy)</fld> <def>the two fundamental principles, one negative, dark, passive, cold, wet, and feminine (yin) and the other (yang) positive, bright, active, dry, hot and masculine.  The interactions and balance of these forces in people and nature influence their behavior and fate.</def> <au>[RHUD]</au><br/
[<source>PJC</source>]</p>

<p><-- p. 1676  --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yis</ent><br/
<hw>Yis</hw> <pr>(?)</pr>, <pos>adv.</pos> <def>Yes.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/<qex>Yis</qex>, sir,<rdquo/ quod he, <ldquo/<qex>yis</qex>, host.<rdquo/</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yit</ent><br/
<hw>Yit</hw> <pr>(?)</pr>, <pos>conj.</pos> <def>Yet.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yite</ent><br/
<hw>Yite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The European yellow-hammer.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yive</ent><br/
<hw>Yive</hw> <pr>(?)</pr>, <pos>v. t. & i.</pos> <def>To give.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>-yl</ent><br/
<hw>-yl</hw> <pr>(?)</pr>. <ety>[Gr. <?/ wood, material.]</ety> <fld>(Chem.)</fld> <def>A suffix used as a characteristic termination of chemical radicals; as in eth<xex>yl</xex>, carbon<xex>yl</xex>, hydrox<xex>yl</xex>, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ <xex>-yl</xex> was first used in 1832 by Liebig and W<oum/hler in naming <xex>benzoyl</xex>, in the sense of <xex>stuff</xex>, or <xex>fundamental material</xex>, then in 1834 by Dumas and Peligot in naming <xex>methyl</xex>, in the sense of <xex>wood</xex>. After this <xex>-yl</xex> was generally used as in <xex>benzoyl</xex>, in the sense of <xex>stuff</xex>, <xex>characteristic ground</xex>, <xex>fundamental material</xex>.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ylang-ylang</ent><br/
<hw>Y*lang`-y*lang"</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Ihlang-ihlang</er>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yle</ent><br/
<hw>Yle</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Isle.</def>  <mark>[Obs.]</mark> <ldquo/The barren <xex>yle</xex>.<rdquo/  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Y level</ent><br/
<hw>Y" lev`el</hw> <pr>(?)</pr>. <fld>(Surv.)</fld> <def>See under <er>Y</er>, <pos>n.</pos></def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ylike</ent><br/
<ent>Yliche</ent><br/
<mhw>{ <hw>Y*liche"</hw> <pr>(?)</pr>, <hw>Y*like"</hw> <pr>(?)</pr> }</mhw>, <pos>a. & adv.</pos> <def>Like; alike.</def>  <mark>[Obs.]</mark> <ldquo/All . . . <xex>yliche</xex> good.<rdquo/  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yllanraton</ent><br/
<hw>Yl`lan*ra*ton"</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From the native name.]</ety> <fld>(Zool.)</fld> <def>The agouara.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ymaked</ent><br/
<hw>Y*mak"ed</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> of <er>Make</er>. <def>Made.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ymel</ent><br/
<hw>Y*mel"</hw> <pr>(?)</pr>, <pos>prep.</pos> <ety>[OE. <ets>ymel</ets>, <ets>imelle</ets>, of Scand. origin; cf. Icel. <ets><imac/ milli</ets>, <ets><imac/ millum</ets> (properly, in the middle, fr. <?/ in + <ets>mi<?/il</ets>, <ets>me<?/al</ets>, middle, akin to E. <ets>middle</ets>), Dan. <ets>imellem</ets>, Sw. <ets>emellan</ets>.  See <er>In</er>, and <er>Middle</er>.]</ety> <def>Among.</def>  <mark>[Obs.]</mark> <ldquo/<xex>Ymel</xex> them all.<rdquo/  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ynambu</ent><br/
<hw>Y*nam"bu</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>A South American tinamou (<spn>Rhynchotus rufescens</spn>); -- called also <altname>perdiz grande</altname>, and <altname>rufous tinamou</altname>.  See <xex>Illust.</xex> of <er>Tinamou</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ynow</ent><br/
<ent>Ynough</ent><br/
<mhw>{ <hw>Y*nough"</hw> <pr>(?)</pr>, <hw>Y*now"</hw> <pr>(?)</pr> }</mhw>, <pos>a.</pos> <ety>[See <er>Enough</er>.]</ety> <def>Enough.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yockel</ent><br/
<hw>Yock"el</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Yokel</er>.]</ety> <fld>(Zool.)</fld> <def>The yaffle.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yode</ent><br/
<hw>Yode</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>imp.</pos> of Go. <ety>[OE. <ets>yode</ets>, <ets>yede</ets>, <ets><yogh/ede</ets>, <ets><yogh/eode</ets>, <ets>eode</ets>, AS. <ets>e<oacute/de</ets>, used as the imp. of <ets>g<amac/n</ets> to go; akin to Goth. <ets>iddja</ets> I, he, went, L. <ets>ire</ets> to go, Gr. <grk>'ie`nai</grk>, Skr. <ets>i</ets>, <ets>y<amac/</ets>. <root/4.  Cf. <er>Issue</er>.]</ety> <def>Went; walked; proceeded.</def>  <altsp>[Written also <asp>yede</asp>.]</altsp> See <er>Yede</er>.<br/
[<source>1913 Webster</source>]</p>

<p><q>Quer [whether] they rade [rode] or <qex>yode</qex>.</q> <rj><qau>Cursor Mundi.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Then into Cornhill anon I <qex>yode</qex>.</q> <rj><qau>Lydgate.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yodle</ent><br/
<ent>Yodel</ent><br/
<mhw>{ <hw>Yo"del</hw> <pr>(?)</pr>, <hw>Yo"dle</hw> <pr>(?)</pr>, }</mhw> <pos>v. t. & i.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yodeled</conjf>, <conjf>Yodled</conjf>; <pos>p. pr. & vb. n.</pos> <conjf>Yodeling</conjf>, <conjf>Yodling</conjf>.]</vmorph> <ety>[G. <ets>jodeln</ets>.]</ety> <def>To sing in a manner common among the Swiss and Tyrolese mountaineers, by suddenly changing from the head voice, or falsetto, to the chest voice, and the contrary; to warble.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yodle</ent><br/
<ent>Yodel</ent><br/
<mhw>{ <hw>Yo"del</hw>, <hw>Yo"dle</hw>  }</mhw>, <pos>n.</pos> <def>A song sung by yodeling, as by the Swiss mountaineers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yodler</ent><br/
<hw>Yo"dler</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who yodels.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yoga</ent><br/
||<hw>Yo"ga</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr. <ets>y<omac/ga</ets> union.]</ety> <def>A species of asceticism among the Hindoos, which consists in a complete abstraction from all worldly objects, by which the votary expects to obtain union with the universal spirit, and to acquire superhuman faculties.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>yogh</ent><br/
<hw>yogh</hw> <pos>n.</pos> <def>An obsolete letter (<yogh/) of the Old English  alphabet, having a pronunciation similar to the modern <ldquo/y<rdquo/.</def><br/
[<source>PJC</source>]</p>

<p><ent>yoghourt</ent><br/
<ent>yoghurt</ent><br/
<ent>yogurt</ent><br/
<hw>yo"ghurt</hw>, <hw>yo"ghourt</hw>, <hw>yo"ghourt</hw> <pos>n.</pos>  <def>custardlike food made from curdled milk.</def><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yogi</ent><br/
<hw>Yo"gi</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr. <ets>y<omac/gin</ets>.]</ety> <def>A follower of the yoga philosophy; an ascetic.</def>  <altsp>[Spelt also <asp>yokin</asp>.]</altsp>  <rj><au>Whitworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yogism</ent><br/
<hw>Yo"gism</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Yoga, or its practice.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yoicks</ent><br/
<hw>Yo"icks</hw> <pr>(?)</pr>, <pos>interj.</pos> <fld>(Hunting)</fld> <def>A cry of encouragement to foxhounds.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yoit</ent><br/
<hw>Yoit</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The European yellow-hammer.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yojan</ent><br/
||<hw>Yo"jan</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Skr. <ets>y<omac/jana</ets>.]</ety> <def>A measure of distance, varying from four to ten miles, but usually about five.</def>  <mark>[India]</mark> <altsp>[Written also <asp>yojana</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yoke</ent><br/
<hw>Yoke</hw> <pr>(y<omac/k)</pr>, <pos>n.</pos> <ety>[OE. <ets>yok</ets>, <ets><yogh/oc</ets>, AS. <ets>geoc</ets>; akin to D. <ets>juk</ets>, OHG. <ets>joh</ets>, G. <ets>joch</ets>, Icel. & Sw. <ets>ok</ets>, Dan. <ets>aag</ets>, Goth. <ets>juk</ets>, Lith. <ets>jungas</ets>, Russ. <ets>igo</ets>, L. <ets>jugum</ets>, Gr. <grk>zy`gon</grk>, Skr. <ets>yuga</ets>, and to L. <ets>jungere</ets> to join, Gr. <?/, Skr. <ets>yui</ets>. <root/109, 280.  Cf. <er>Join</er>, <er>Jougs</er>, <er>Joust</er>, <er>Jugular</er>, <er>Subjugate</er>, <er>Syzygy</er>, <er>Yuga</er>, <er>Zeugma</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>A bar or frame of wood by which two oxen are joined at the heads or necks for working together.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>A yearling bullock to thy name shall smoke,<br/
Untamed, unconscious of the galling <qex>yoke</qex>.</q> <rj><qau>Pope.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The modern yoke for oxen is usually a piece of timber hollowed, or made curving, near each end, and laid on the necks of the oxen, being secured in place by two bows, one inclosing each neck, and fastened through the timber. In some countries the yoke consists of a flat piece of wood fastened to the foreheads of the oxen by thongs about the horns.</note><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>A frame or piece resembling a yoke, as in use or shape.</def>  Specifically: <sd>(a)</sd> <def>A frame of wood fitted to a person's shoulders for carrying pails, etc., suspended on each side; <as>as, a milkmaid's <ex>yoke</ex></as>.</def>  <sd>(b)</sd> <def>A frame worn on the neck of an animal, as a cow, a pig, a goose, to prevent passage through a fence.</def>  <sd>(c)</sd> <def>A frame or convex piece by which a bell is hung for ringing it.  See <xex>Illust.</xex> of <er>Bell</er>.</def>  <sd>(d)</sd> <def>A crosspiece upon the head of a boat's rudder.  To its ends lines are attached which lead forward so that the boat can be steered from amidships.</def>  <sd>(e)</sd> <fld>(Mach.)</fld> <def>A bent crosspiece connecting two other parts.</def>  <sd>(f)</sd> <fld>(Arch.)</fld> <def>A tie securing two timbers together, not used for part of a regular truss, but serving a temporary purpose, as to provide against unusual strain.</def>  <sd>(g)</sd> <fld>(Dressmaking)</fld> <def>A band shaped to fit the shoulders or the hips, and joined to the upper full edge of the waist or the skirt.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fig.: That which connects or binds; a chain; a link; a bond connection.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Boweth your neck under that blissful <qex>yoke</qex> . . . <br/
Which that men clepeth spousal or wedlock.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>This <qex>yoke</qex> of marriage from us both remove.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>A mark of servitude; hence, servitude; slavery; bondage; service.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Our country sinks beneath the <qex>yoke</qex>.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My <qex>yoke</qex> is easy, and my burden is light.</q> <rj><qau>Matt. xi. 30.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>5.</sn> <def>Two animals yoked together; a couple; a pair that work together.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>I have bought five <qex>yoke</qex> of oxen, and I go to prove them.</q> <rj><qau>Luke xiv. 19.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>6.</sn> <def>The quantity of land plowed in a day by a yoke of oxen.</def>  <mark>[Obs.]</mark>  <rj><au>Gardner.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>7.</sn> <def>A portion of the working day; <as>as, to work two <ex>yokes</ex>, that is, to work both portions of the day, or morning and afternoon</as>.</def>  <mark>[Prov. Eng.]</mark>  <rj><au>Halliwell.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>8.</sn> <fld>(Chiefly Mach.)</fld> <def>A clamp or similar piece that embraces two other parts to hold or unite them in their respective or relative positions, as a strap connecting a slide valve to the valve stem, or the soft iron block or bar permanently connecting the pole pieces of an electromagnet, as in a dynamo.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><cs><mcol><col><b>Neck yoke</b></col>, <col><b>Pig yoke</b></col></mcol>. <cd>See under <er>Neck</er>, and <er>Pig</er>.</cd> -- <col><b>Yoke elm</b></col> <fld>(Bot.)</fld>, <cd>the European hornbeam (<spn>Carpinus Betulus</spn>), a small tree with tough white wood, often used for making yokes for cattle.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yoke</ent><br/
<hw>Yoke</hw> <pr>(?)</pr>, <pos>v. t.</pos> <vmorph>[<pos>imp. & p. p.</pos> <conjf>Yoked</conjf> <pr>(?)</pr>; <pos>p. pr. & vb. n.</pos> <conjf>Yoking</conjf>.]</vmorph><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>To put a yoke on; to join in or with a yoke; <as>as, to <ex>yoke</ex> oxen, or pair of oxen</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>To couple; to join with another.</def>  <ldquo/Be ye not unequally <xex>yoked</xex> with unbelievers.<rdquo/  <rj><au>2 Cor. vi. 14.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Cassius, you are <qex>yoked</qex> with a lamb.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>To enslave; to bring into bondage; to restrain; to confine.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Then were they <qex>yoked</qex> with garrisons.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The words and promises that <qex>yoke</qex><br/
The conqueror are quickly broke.</q> <rj><qau>Hudibras.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yoke</ent><br/
<hw>Yoke</hw>, <pos>v. i.</pos> <def>To be joined or associated; to be intimately connected; to consort closely; to mate.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>We 'll <qex>yoke</qex> together, like a double shadow.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yokeage</ent><br/
<hw>Yoke"age</hw> <pr>(?)</pr>, <pos>n.</pos> <def>See <er>Rokeage</er>.</def>  <mark>[Local, U. S.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yokefellow</ent><br/
<hw>Yoke"fel`low</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[<ets>Yoke</ets> + <ets>fellow</ets>.]</ety> <def>An associate or companion in, or as in; a mate; a fellow; especially, a partner in marriage.</def>  <rj><au>Phil. iv. 3.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The two languages [English and French] became <qex>yokefellows</qex> in a still more intimate manner.</q> <rj><qau>Earle.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those who have most distinguished themselves by railing at the sex, very often choose one of the most worthless for a companion and <qex>yokefellow</qex>.</q> <rj><qau>Addison.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yokel</ent><br/
<hw>Yo"kel</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perhaps from an AS. word akin to E. <ets>gawk</ets>.]</ety> <def>A country bumpkin.</def>  <mark>[Eng.]</mark>  <rj><au>Dickens.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yokelet</ent><br/
<hw>Yoke"let</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A small farm; -- so called as requiring but one yoke of oxen to till it.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yokemate</ent><br/
<hw>Yoke"mate`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Same as <er>Yokefellow</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yoke-toed</ent><br/
<hw>Yoke"-toed`</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Zool.)</fld> <def>Having two toes in front and two behind, as the trogons and woodpeckers.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yold</ent><br/
<hw>Yold</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> of <er>Yield</er>. <def>Yielded.</def>  <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yolden</ent><br/
<hw>Yold"en</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> of <er>Yield</er>. <def>Yielded.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yolk</ent><br/
<hw>Yolk</hw> <pr>(y<omac/lk <it>or</it> y<omac/k; 277)</pr>, <pos>n.</pos> <ety>[OE. <ets>yolke</ets>, <ets>yelke</ets>, <ets><yogh/olke</ets>, <ets><yogh/elke</ets>, AS. <ets>geoloca</ets>, <ets>geoleca</ets>, fr. <ets>geolu</ets> yellow.  See <er>Yellow</er>.]</ety> <altsp>[Written also <asp>yelk</asp>.]</altsp><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The yellow part of an egg; the vitellus.</def><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <fld>(Zool.)</fld> <def>An oily secretion which naturally covers the wool of sheep.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yolk cord</b></col> <fld>(Zool.)</fld>, <cd>a slender cord or duct which connects the yolk glands with the egg chambers in certain insects, as in the aphids.</cd> -- <col><b>Yolk gland</b></col> <fld>(Zool.)</fld>, <cd>a special organ which secretes the yolk of the eggs in many turbellarians, and in some other invertebrates.  See <xex>Illust.</xex> of <er>Hermaphrodite</er> in Appendix.</cd> -- <col><b>Yolk sack</b></col> <fld>(Anat.)</fld>, <cd>the umbilical vesicle.  See under <er>Unbilical</er>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yoll</ent><br/
<hw>Yoll</hw> <pr>(y<omac/l)</pr>, <pos>v. i.</pos> <def>To yell.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yom</ent><br/
<hw>Yom</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Heb. <ets>y<omac/m</ets>.]</ety> <def>Day; -- a Hebrew word used in the names of various Jewish feast days; <as>as, <ex>Yom Kippur</ex>, the Day of Atonement; <ex>Yom Teruah</ex> (lit., day of shouting), the Feast of Trumpets</as>.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yom Kippur</ent><br/
<hw>Yom` Kip*pur"</hw> <pr>(y<omac/m`k<icr/*p<oocr/r", y<aum/m`k<icr/*p<oocr/r")</pr>, <ety>[Heb. y<omac/m kipp<umac/r, day of atonement.]</ety> <fld>(Jewish Antiq.)</fld> <def>the only fast day of the Mosaic ritual, celebrated on the tenth day of the seventh month (Tishri), according to the rites described in Leviticus xvi. Also called <altname>Day of Atonement</altname>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Yon</ent><br/
<hw>Yon</hw> <pr>(y<ocr/n)</pr>, <pos>a.</pos> <ety>[OE. <ets>yon</ets>, <ets><yogh/on</ets>, AS. <ets>geon</ets>; akin to G. <ets>jener</ets>, OHG. <ets>jen<emac/r</ets>, Icel. <ets>enn</ets>, <ets>inn</ets>; cf. Goth. <ets>jains</ets>. <root/188.  Cf. <er>Beyond</er>, <er>Yond</er>, <er>Yonder</er>.]</ety> <def>At a distance, but within view; yonder.</def>  <mark>[Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>Read thy lot in <qex>yon</qex> celestial sign.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Though fast <qex>yon</qex> shower be fleeting.</q> <rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yon</ent><br/
<hw>Yon</hw>, <pos>adv.</pos> <def>Yonder.</def>  <mark>[Obs. or Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>But, first and chiefest, with thee bring<br/
Him that <qex>yon</qex> soars on golden wing.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yoncopin</ent><br/
<hw>Yon"co*pin</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Perhaps corrupted from Illinois <ets>micoupena</ets>, Chippewa <ets>makopin</ets>, the American lotus.]</ety> <fld>(Bot.)</fld> <def>A local name in parts of the Mississippi Valley for the American lotus (<spn>Nelumbo lutea</spn>).</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yond</ent><br/
<hw>Yond</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Cf. AS. <ets>anda</ets>, <ets>onda</ets>, anger, <ets>andian</ets> to be angry.]</ety> <def>Furious; mad; angry; fierce.</def>  <mark>[Obs.]</mark> <ldquo/Then wexeth wood and <xex>yond</xex>.<rdquo/  <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yond</ent><br/
<hw>Yond</hw>, <pos>adv. & a.</pos> <ety>[OE. <ets>yond</ets>, <ets><yogh/ond</ets>, <ets><yogh/eond</ets>, through, beyond, over, AS. <ets>geond</ets>, adv. & prep.; cf. Goth. <ets>jaind</ets> thither. <root/188.  See <er>Yon</er>, <pos>a.</pos>]</ety> <def>Yonder.</def>  <mark>[Obs.]</mark> <ldquo/<xex>Yond</xex> in the garden.<rdquo/  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yonder</ent><br/
<hw>Yon"der</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[OE. <ets>yonder</ets>, <ets><yogh/onder</ets>; cf. OD. <ets>ginder</ets>, Goth. <ets>jaindr<?/</ets> there. <?/<?/<?/<?/.  See <er>Yond</er>, <pos>adv.</pos>]</ety> <def>At a distance, but within view.</def><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Yonder</qex> are two apple women scolding.</q> <rj><qau>Arbuthnot.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yonder</ent><br/
<hw>Yon"der</hw>, <pos>a.</pos> <def>Being at a distance within view, or conceived of as within view; that or those there; yon.</def>  <ldquo/Yon flowery arbors, <xex>yonder</xex> alleys green.<rdquo/ <au>Milton.</au> <ldquo/<xex>Yonder</xex> sea of light.<rdquo/ <au>Keble.</au><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Yonder</qex> men are too many for an embassage.</q> <rj><qau>Bacon.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yoni</ent><br/
||<hw>Yo"ni</hw> <pr>(y<omac/"n<emac/)</pr>, <pos>n.</pos> <ety>[Skr. <ets>y<omac/ni</ets>.]</ety> <fld>(Hindu Myth.)</fld> <def>The symbol under which Sakti, or the personification of the female power in nature, is worshiped.  Cf. <er>Lingam</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yonker</ent><br/
<hw>Yon"ker</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Younker</er>.]</ety> <def>A young fellow; a younker.</def>  <mark>[Obs. or Colloq.]</mark>  <rj><au>Sir W. Scott.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yore</ent><br/
<hw>Yore</hw> <pr>(y<omac/r)</pr>, <pos>adv.</pos> <ety>[OE. <ets><yogh/ore</ets>, <ets>yare</ets>, <ets><yogh/are</ets>, AS. <ets>ge<aacute/ra</ets>;akin to <ets>ge<aacute/r</ets> a year, E. <ets>year</ets>. <root/204.  See <er>Year</er>.]</ety> <def>In time long past; in old time; long since.</def>  <mark>[Obs. or Poetic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>As it hath been of olde times <qex>yore</qex>.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Which though he hath polluted oft and <qex>yore</qex>,<br/
Yet I to them for judgment just do fly.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Of yore</b></col>, <cd>of old time; long ago; as, in times or days <xex>of yore</xex>.</cd> <ldquo/But Satan now is wiser than <xex>of yore</xex>.<rdquo/  <rj><au>Pope.</au></rj>
</cs><br/
[<source>1913 Webster</source>]</p>

<p><q>Where Abraham fed his flock <qex>of yore</qex>.</q> <rj><qau>Keble.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yorker</ent><br/
<hw>York"er</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Cricket)</fld> <def>A tice.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>York rite</ent><br/
<hw>York rite</hw> <pr>(?)</pr>. <fld>(Freemasonry)</fld> <def>The rite or ceremonial observed by one of the Masonic systems, deriving its name from the city of <etsep>York</etsep>, in England; also, the system itself, which, in England, confers only the first three degrees.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yorkshire</ent><br/
<hw>York"shire</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A county in the north of England.</def><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yorkshire grit</b></col>, <cd>a kind of stone used for polishing marble, and copperplates for engravers.</cd> <au>Simmonds.</au> -- <col><b>Yorkshire pudding</b></col>, <cd>a batter pudding baked under meat.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>York use</ent><br/
<hw>York" use`</hw> <pr>(?)</pr>. <fld>(Eccl.)</fld> <def>The one of the three printed uses of England which was followed in the north. It was based on the Sarum use.  See <er>Use</er>, <altname>n</altname>., 6.</def>  <rj><au>Shipley.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yot</ent><br/
<hw>Yot</hw> <pr>(?)</pr>, <pos>v. t.</pos> <def>To unite closely.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yote</ent><br/
<hw>Yote</hw> <pr>(y<omac/t)</pr>, <pos>v. t.</pos> <ety>[OE. <ets><yogh/eoten</ets>, <ets><yogh/eten</ets>, to pour, AS. <ets>ge<oacute/tan</ets>.  See <er>Found</er> to cast.]</ety> <def>To pour water on; to soak in, or mix with, water.</def>  <mark>[Obs. or Prov. Eng.]</mark>  <rj><au>Grose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>My fowls, which well enough,<br/
I, as before, found feeding at their trough<br/
Their <qex>yoted</qex> wheat.</q> <rj><qau>Chapman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>You</ent><br/
<hw>You</hw> <pr>(<umac/)</pr>, <pos>pron.</pos> <nmorph>[<pos>Possess.</pos> <decf>Your</decf> <pr>(<umac/r)</pr> or <decf>Yours</decf> <pr>(<umac/rz)</pr>; <pos>dat. & obj.</pos> <decf>You</decf>.]</nmorph> <ety>[OE. <ets>you</ets>, <ets>eou</ets>, <ets>eow</ets>, dat. & acc., AS. <ets>e<oacute/w</ets>, used as dat. & acc. of <ets>ge</ets>, <ets>g<emac/</ets>, ye; akin to OFries. <ets>iu</ets>, <ets>io</ets>, D. <ets>u</ets>, G. <ets>euch</ets>, OHG. <ets>iu</ets>, dat., <ets>iuwih</ets>, acc., Icel. <ets>y<edh/r</ets>, dat. & acc., Goth. <ets>izwis</ets>; of uncertain origin. <root/189.  Cf. <er>Your</er>.]</ety> <def>The pronoun of the second person, in the nominative, dative, and objective case, indicating the person or persons addressed.  See the Note under <er>Ye</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Ye go to Canterbury; God <qex>you</qex> speed.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Good sir, I do in friendship counsel <qex>you</qex><br/
To leave this place.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>In vain <qex>you</qex> tell your parting lover<br/
<qex>You</qex> wish fair winds may waft him over.</q> <rj><qau>Prior.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Though <xex>you</xex> is properly a plural, it is in all ordinary discourse used also in addressing a single person, yet properly always with a plural verb. <ldquo/Are <xex>you</xex> he that hangs the verses on the trees, wherein Rosalind is so admired ?<rdquo/ <au>Shak.</au>
   <xex>You</xex> and <xex>your</xex> are sometimes used indefinitely, like <xex>we</xex>, <xex>they</xex>, <xex>one</xex>, to express persons not specified. <ldquo/The looks at a distance like a new-plowed land; but as <xex>you</xex> come near it, <xex>you</xex> see nothing but a long heap of heavy, disjointed clods.<rdquo/ <au>Addison.</au> <ldquo/<xex>Your</xex> medalist and critic are much nearer related than the world imagine.<rdquo/ <au>Addison.</au> <ldquo/It is always pleasant to be forced to do what <xex>you</xex> wish to do, but what, until pressed, <xex>you</xex> dare not attempt.<rdquo/ <au>Hook.</au>
   <xex>You</xex> is often used reflexively for <xex>yourself</xex> of <xex>yourselves</xex>. <ldquo/Your highness shall repose <xex>you</xex> at the tower.<rdquo/  <au>Shak.</au></note><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youl</ent><br/
<hw>Youl</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>To yell; to yowl.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Young</ent><br/
<hw>Young</hw> <pr>(y<ucr/ng)</pr>, <pos>a.</pos> <amorph>[<pos>Compar.</pos> <adjf>Younger</adjf> <pr>(y<ucr/<nsm/"g<etil/r)</pr>; <pos>superl.</pos> <adjf>Youngest</adjf> <pr>(-g<ecr/st)</pr>.]</amorph> <ety>[OE. <ets>yung</ets>, <ets>yong</ets>, <ets><yogh/ong</ets>, <ets><yogh/ung</ets>, AS. <ets>geong</ets>; akin to OFries. <ets>iung</ets>, <ets>iong</ets>, D. <ets>joing</ets>, OS., OHG., & G. <ets>jung</ets>, Icel. <ets>ungr</ets>, Sw. & Dan. <ets>ung</ets>, Goth. <ets>juggs</ets>, Lith. <ets>jaunas</ets>, Russ. <ets>iunuii</ets>, L. <ets>juvencus</ets>, <ets>juvenis</ets>, Skr. <ets>juva<cced/a</ets>, <ets>juvan</ets>. <root/281.  Cf. <er>Junior</er>, <er>Juniper</er>, <er>Juvenile</er>, <er>Younker</er>, <er>Youth</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>Not long born; still in the first part of life; not yet arrived at adolescence, maturity, or age; not old; juvenile; -- said of animals; <as>as, a <ex>young</ex> child; a <ex>young</ex> man; a <ex>young</ex> fawn</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>For he so <qex>young</qex> and tender was of age.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/Whom the gods love, die <qex>young</qex>,<rdquo/ has been too long carelessly said; . . . whom the gods love, live <qex>young</qex> forever.</q> <rj><qau>Mrs. H. H. Jackson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Being in the first part, pr period, of growth; <as>as, a <ex>young</ex> plant; a <ex>young</ex> tree</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>While the fears of the people were <qex>young</qex>.</q> <rj><qau>De Foe.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Having little experience; inexperienced; unpracticed; ignorant; weak.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Come, come, elder brother, you are too <qex>young</qex> in this.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Young</ent><br/
<hw>Young</hw>, <pos>n.</pos> <def>The offspring of animals, either a single animal or offspring collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>[The egg] bursting with kindly rupture, forth disclosed<br/
Their callow <qex>young</qex>.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>With young</b></col>, <cd>with child; pregnant.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>young-bearing</ent><br/
<hw>young"-bear*ing</hw> <pr>(?)</pr>, <pos>adj.</pos> <sn>1.</sn>  <fld>(Zool.)</fld> <def>being the sex that produces ova and carries the fetus to a point where it can live outside the parent; -- of animals.</def> <mark>[prenominal]</mark><br/
<syn><b>Syn. --</b> egg-producing(prenominal).</syn><br/
[<source>WordNet 1.5</source> <source>+PJC</source>]</p>

<p><ent>young-begetting</ent><br/
<hw>young"-be*get`ting</hw> <pr>(?)</pr>, <pos>adj.</pos>  <fld>(Biology)</fld> <def>Being the sex (of plant or animal) that produces gametes (spermatozoa) that perform the fertilizing function in generation, usually male.  In contradistinction to <contr>female</contr> or <contr>androgynous</contr>.</def><br/
<syn><b>Syn. --</b> male.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Younger</ent><br/
<hw>Young"er</hw> <pr>(?)</pr>, <pos>n.</pos> <def>One who is younger; an inferior in age; a junior.</def>  <ldquo/The elder shall serve the <xex>younger</xex>.<rdquo/  <rj><au>Rom. ix. 12.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Used of the younger of two persons of the same name especially used to distinguish a son from his father; -- usually used postpositionally; <as>as, Henry the <ex>younger</ex></as>.</def><br/
<syn><b>Syn. --</b> jr.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Youngish</ent><br/
<hw>Young"ish</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Somewhat young.</def>  <rj><au>Tatler.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youngling</ent><br/
<hw>Young"ling</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>geongling</ets>.]</ety> <def>A young person; a youth; also, any animal in its early life.</def>  <ldquo/More dear . . . than <xex>younglings</xex> to their dam.<rdquo/  <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>He will not be so willing, I think, to join with you as with us <qex>younglings</qex>.</q> <rj><qau>Ridley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youngling</ent><br/
<hw>Young"ling</hw>, <pos>a.</pos> <def>Young; youthful.</def>  <rj><au>Wordsworth.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youngly</ent><br/
<hw>Young"ly</hw>, <pos>a.</pos> <ety>[AS. <ets>geonglic</ets>.]</ety> <def>Like a young person or thing; young; youthful.</def>  <mark>[Obs.]</mark>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youngly</ent><br/
<hw>Young"ly</hw>, <pos>adv.</pos> <sn>1.</sn> <def>In a young manner; in the period of youth; early in life.</def>  <mark>[Obs.]</mark>  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Ignorantly; weakly.</def>  <mark>[R.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Young Men's Christian Association</ent><br/
<hw>Young Men's Christian Association</hw>. <def>An organization for promoting the spiritual, intellectual, social, and physical welfare of young men, founded, June 6, 1844, by George Williams (knighted therefor by Queen Victoria) in London. In 1851 it extended to the United States and Canada, and in 1855 representatives of similar organizations throughout Europe and America formed an international body. The movement has successfully expanded not only among young men in general, but also specifically among railroad men, in the army and navy, with provision for Indians and negroes, and a full duplication of all the various lines of oepration in the boys' departments.  It currently (1998) maintains buildings which usually have both recreational facilities and dormitories for dwelling.  It is usually called by its acronym <altname>YMCA</altname>.  See also the similar organizations <er>Young Women's Christian Association</er> and <er>YMHA</er>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Youngness</ent><br/
<hw>Young"ness</hw>, <pos>n.</pos> <def>The quality or state of being young.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Young one</ent><br/
<hw>Young one</hw>. <def>A young human being; a child; also, a young animal, as a colt.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Youngster</ent><br/
<hw>Young"ster</hw> <pr>(?)</pr>, <pos>n.</pos> <def>A young person; a youngling; a lad.</def>  <mark>[Colloq.]</mark> <ldquo/He felt himself quite a <xex>youngster</xex>, with a long life before him.<rdquo/  <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youngth</ent><br/
<hw>Youngth</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Youth.</def>  <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><qex>Youngth</qex> is a bubble blown up with breath.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youngthly</ent><br/
<hw>Youngth"ly</hw>, <pos>a.</pos> <def>Pertaining to, or resembling, youth; youthful.</def>  <mark>[Obs.]</mark>  <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Young'un</ent><br/
<hw>Young'un</hw>. <def>A young human being; -- a contraction of <er>young one</er>.</def><br/
[<source>PJC</source>]</p>

<p><ent>Young Women's Christian Association</ent><br/
<hw>Young Women's Christian Association</hw>. <def>An organization for promoting the spiritual, intellectual, social, and economic welfare of young women, originating in 1855 with Lady Kinnaird's home for young women, and Miss Emma Robert's prayer union for young women,in England, which were combined in the year 1884 as a national association. Now nearly all the civilized countries, and esp. the United States, have local, national, and international organizations.  See also the similar organizations <er>Young Men's Christian Association</er> and <er>YMHA</er>.</def><br/
[<source>Webster 1913 Suppl.</source> <source>+PJC</source>]</p>

<p><ent>Younker</ent><br/
<hw>Youn"ker</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[D. <ets>jonker</ets>, <ets>jonkeer</ets>; <ets>jong</ets> young + <ets>heer</ets> a lord, sir, gentleman.  See <er>Young</er>, <pos>a.</pos>]</ety> <def>A young person; a stripling; a yonker.</def>  <mark>[Obs. or Colloq.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q>That same <qex>younker</qex> soon was overthrown.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youpon</ent><br/
<hw>You"pon</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>Same as <er>Yaupon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Your</ent><br/
<hw>Your</hw> <pr>(<umac/r)</pr>, <pos>pron. & a.</pos> <ety>[OE. <ets>your</ets>, <ets><yogh/our</ets>, <ets>eowr</ets>, <ets>eower</ets>, AS. <ets>e<oacute/wer</ets>, originally used as the gen. of <ets>ge</ets>, <ets>g<emac/</ets>, ye; akin to OFries. <ets>iuwer</ets> your, OS. <ets>iuwar</ets>, D. <ets>uw</ets>, OHG. <ets>iuw<emac/r</ets>, G. <ets>euer</ets>, Icel. <ets>y<edh/ar</ets>, Goth. <ets>izwara</ets>, <ets>izwar</ets>, and E. <ets>you</ets>. <root/189.  See <er>You</er>.]</ety> <def>The form of the possessive case of the personal pronoun <xex>you</xex>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The possessive takes the form <xex>yours</xex> when the noun to which it refers is not expressed, but implied; as, this book is <xex>yours</xex>. <ldquo/An old fellow of <xex>yours</xex>.<rdquo/</note>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yours</ent><br/
<hw>Yours</hw> <pr>(<uum/rz)</pr>, <pos>pron.</pos> <def>See the Note under <er>Your</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yourself</ent><br/
<hw>Your*self"</hw> <pr>(?)</pr>, <pos>pron.</pos>; <plu><it>pl.</it> <plw>Yourselves</plw> <pr>(?)</pr>.</plu> <ety>[<ets>Your</ets> + <ets>self</ets>.]</ety> <def>An emphasized or reflexive form of the pronoun of the second person; -- used as a subject commonly with <xex>you</xex>; <as>as, you <ex>yourself</ex> shall see it</as>; also, alone in the predicate, either in the nominative or objective case; <as>as, you have injured <ex>yourself</ex></as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Of which right now ye han <qex>yourselve</qex> heard.</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>If <qex>yourselves</qex> are old, make it your cause.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Why should you be so cruel to <qex>yourself</qex> ?</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>The religious movement which you <qex>yourself</qex>, as well as I, so faithfully followed from first to last.</q> <rj><qau>J. H. Newman.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youth</ent><br/
<hw>Youth</hw> <pr>(<umac/th)</pr>, <pos>n.</pos>; <plu><it>pl.</it> <plw>Youths</plw> <pr>(<umac/ths; 264)</pr> or <xex>collectively</xex> <plw>Youth</plw>.</plu> <ety>[OE. <ets>youthe</ets>, <ets>youh<thorn/e</ets>, <ets><yogh/uhe<edh/e</ets>, <ets><yogh/uwe<edh/e</ets>, <ets><yogh/eo<yogh/e<edh/e</ets>, AS. <ets>geogu<edh/</ets>, <ets>geogo<edh/</ets>; akin to OS. <ets>jugu<edh/</ets>, D. <ets>jeugd</ets>, OHG. <ets>jugund</ets>, G. <ets>jugend</ets>, Goth. <ets>junda</ets>. <ets><root/281</ets>.  See <er>Young</er>.]</ety><br/
[<source>1913 Webster</source>]</p>

<p><sn>1.</sn> <def>The quality or state of being young; youthfulness; juvenility.</def>  <ldquo/In my flower of <xex>youth</xex>.<rdquo/  <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Such as in his face<br/
<qex>Youth</qex> smiled celestial.</q> <rj><qau>Milton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>The part of life that succeeds to childhood; the period of existence preceding maturity or age; the whole early part of life, from childhood, or, sometimes, from infancy, to manhood.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>He wondered that your lordship<br/
Would suffer him to spend his <qex>youth</qex> at home.</q> <rj><qau>Shak.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>Those who pass their <qex>youth</qex> in vice are justly condemned to spend their age in folly.</q> <rj><qau>Rambler.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>A young person; especially, a young man.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>Seven <qex>youths</qex> from Athens yearly sent.</q> <rj><qau>Dryden.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>4.</sn> <def>Young persons, collectively.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>It is fit to read the best authors to <qex>youth</qex> first.</q> <rj><qau>B. Jonson.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><-- p. 1677 --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youthful</ent><br/
<hw>Youth"ful</hw> <pr>(?)</pr>, <pos>a.</pos> <sn>1.</sn> <def>Not yet mature or aged; young.</def>  <ldquo/Two <xex>youthful</xex> knights.<rdquo/ <au>Dryden.</au> <def>Also used figuratively.</def>  <ldquo/The <xex>youthful</xex> season of the year.<rdquo/  <rj><au>Shak.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>2.</sn> <def>Of or pertaining to the early part of life; suitable to early life; <as>as, <ex>youthful</ex> days; <ex>youthful</ex> sports.</as></def> <ldquo/Warm, <xex>youthful</xex> blood.<rdquo/ <au>Shak.</au> <ldquo/<xex>Youthful</xex> thoughts.<rdquo/  <rj><au>Milton.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><sn>3.</sn> <def>Fresh; vigorous, as in youth.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>After millions of millions of ages . . . still <qex>youthful</qex> and flourishing.</q> <rj><qau>Bentley.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><syn><b>Syn.</b> -- Puerile; juvenile.</syn> <usage> -- <er>Youthful</er>, <er>Puerile</er>, <er>Juvenile</er>. <xex>Puerile</xex> is always used in a bad sense, or at least in the sense of what is suitable to a boy only; <as>as, <ex>puerile</ex> objections, <ex>puerile</ex> amusements, etc</as>. <xex>Juvenile</xex> is sometimes taken in a bad sense, as when speaking of youth in contrast with manhood; <as>as, <ex>juvenile</ex> tricks; a <ex>juvenile</ex> performance</as>. <xex>Youthful</xex> is commonly employed in a good sense; <as>as, <ex>youthful</ex> aspirations</as>; or at least by way of extenuating; <as>as, <ex>youthful</ex> indiscretions</as>. <ldquo/Some men, imagining themselves possessed with a divine fury, often fall into toys and trifles, which are only <xex>puerilities</xex>.<rdquo/ <au>Dryden.</au> <ldquo/Raw, <xex>juvenile</xex> writers imagine that, by pouring forth figures often, they render their compositions warm and animated.<rdquo/</usage>  <rj><au>Blair.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p>-- <wordforms><wf>Youth"ful*ly</wf>, <pos>adv.</pos> -- <wf>Youth"ful*ness</wf>, <pos>n.</pos></wordforms><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youthhood</ent><br/
<hw>Youth"hood</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[AS. <ets>geogu<edh/h<amac/d</ets>.  See <er>Youth</er>, and <er>-hood</er>.]</ety> <def>The quality or state of being a youth; the period of youth.</def>  <rj><au>Cheyne.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youthly</ent><br/
<hw>Youth"ly</hw>, <pos>a.</pos> <ety>[AS. <ets>geogu<edh/lic</ets>.]</ety> <def>Young; youthful.</def>  <mark>[Obs.]</mark> <ldquo/All my <xex>youthly</xex> days.<rdquo/  <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>youth-on-age</ent><br/
<hw>youth`-on-age"</hw> <pos>n.</pos> <fld>(Bot.)</fld>  <def>A vigorous perennial herb (<spn>Tolmiea menziesii</spn>) with flowers in erect racemes and having young plants develop at the junction of a leaf blade and the leafstalk.</def><br/
<syn><b>Syn. --</b> pickaback plant, piggyback plant.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Youthsome</ent><br/
<hw>Youth"some</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Youthful.</def>  <mark>[Obs.]</mark>  <rj><au>Pepys.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youthy</ent><br/
<hw>Youth"y</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Young.</def>  <mark>[Obs.]</mark>  <rj><au>Spectator.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Youze</ent><br/
<hw>Youze</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[From a native East Indian name.]</ety> <fld>(Zool.)</fld> <def>The cheetah.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yow</ent><br/
<hw>Yow</hw> <pr>(?)</pr>, <pos>pron.</pos> <def>You.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yowe</ent><br/
<hw>Yowe</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[See <er>Ewe</er>.]</ety> <fld>(Zool.)</fld> <def>A ewe.</def>  <mark>[Prov. Eng. & Scot.]</mark>  <rj><au>G. Eliot.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yowl</ent><br/
<hw>Yowl</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[See <er>Yawl</er>, <pos>v. i.</pos>]</ety> <def>To utter a loud, long, and mournful cry, as a dog; to howl; to yell.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yowl</ent><br/
<hw>Yowl</hw>, <pos>n.</pos> <def>A loud, protracted, and mournful cry, as that of a dog; a howl.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yowley</ent><br/
<hw>Yow"ley</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Cf. <er>Yellow</er>.]</ety> <fld>(Zool.)</fld> <def>The European yellow-hammer.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yox</ent><br/
<hw>Yox</hw> <pr>(?)</pr>, <pos>v. i.</pos> <def>See <er>Yex</er>.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ypight</ent><br/
<hw>Y*pight"</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> of <er>Pitch</er>. <def>See <er>Pight</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ypocras</ent><br/
<hw>Yp"o*cras</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Hippocras.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ypres lace</ent><br/
<hw>Y"pres lace`</hw> <pr>(?)</pr>. <def>Fine bobbin lace made at <xex>Ypres</xex> in Belgium, usually exactly like Valenciennes lace.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ypsiliform</ent><br/
<hw>Yp*sil"i*form</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[Gr. <?/ <?/ the name of the letter <?/ + <ets>-form</ets>.]</ety> <fld>(Biol.)</fld> <def>Resembling the <?/ in appearance; -- said of the germinal spot in the ripe egg at one of the stages of fecundation.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ypsiloid</ent><br/
<hw>Yp"si*loid</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Anat.)</fld> <def>In the form of the letter <er>Y</er>; <er>Y-</er>shaped.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yraft</ent><br/
<hw>Y*raft"</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> of <er>Reave</er>. <def>Bereft.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yren</ent><br/
<hw>Yr"en</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Iron.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yronne</ent><br/
<hw>Y*ron"ne</hw> <pr>(?)</pr>, <mark>obs.</mark> <pos>p. p.</pos> of <er>Run</er>. <def>Run.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ysame</ent><br/
<hw>Y*same"</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[See <er>Same</er>.]</ety> <def>Together.</def>  <mark>[Obs.]</mark> <ldquo/And in a bag all sorts of seeds <xex>ysame</xex>.<rdquo/  <rj><au>Spenser.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yt</ent><br/
<mhw>{ <hw>Y<supr>t</supr></hw>, <hw>Yt</hw> <pr>(<th/<acr/t)</pr> }</mhw>, <def>An old method of printing <sig>that</sig> (AS. <xex><thorn/<ae/t</xex>, <xex><edh/<ae/t</xex>) the <ldquo/y<rdquo/ taking the place of the old letter <ldquo/thorn<rdquo/ (<thorn/).  Cf. <er>Ye</er>, the.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ythrowe</ent><br/
<hw>Y*throwe"</hw> <pr>(?)</pr>, <mark>obs.</mark> <def><pos>p. p.</pos> of Throw.</def>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ytterbic</ent><br/
<hw>Yt*ter"bic</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld> <def>Pertaining to, or derived from, ytterbium; containing ytterbium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ytterbium</ent><br/
<hw>Yt*ter"bi*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., fr. <ets>Ytterby</ets>, in Sweden.  See <er>Erbium</er>.]</ety> <fld>(Chem.)</fld> <def>A rare element of the boron group, sometimes associated with yttrium or other related elements, as in euxenite and gadolinite. Symbol Yb; provisional atomic weight 173.2.  Cf. <er>Yttrium</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ Ytterbium is associated with other rare elements, and probably has not been prepared in a pure state.</note>
<-- purified before 1960 --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yttria</ent><br/
<hw>Yt"tri*a</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL.  See <er>Yttrium</er>.]</ety> <fld>(Chem.)</fld> <def>The oxide, <chform>Y2O3</chform>, or earth, of yttrium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yttric</ent><br/
<hw>Yt"tric</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld> <def>Pertaining to, derived from, or containing, yttrium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yttriferous</ent><br/
<hw>Yt*trif"er*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Bearing or containing yttrium or the allied elements; <as>as, gadolinite is one of the <ex>yttriferous</ex> minerals</as>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yttrious</ent><br/
<hw>Yt"tri*ous</hw> <pr>(?)</pr>, <pos>a.</pos> <fld>(Chem.)</fld> <def>Same as <er>Yttric</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yttrium</ent><br/
<hw>Yt"tri*um</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from <ets>Ytter</ets>by, in Sweden.  See <er>Erbium</er>.]</ety> <fld>(Chem.)</fld> <def>A rare metallic element of the boron-aluminium group, found in gadolinite and other rare minerals, and extracted as a dark gray powder.  Symbol <it>Y</it>.  Atomic number 39.  Atomic weight, 88.9.</def>  <altsp>[Written also <asp>ittrium</asp>.]</altsp><br/
[<source>1913 Webster</source> <source>+PJC</source>]</p>

<p><note><hand/ Associated with yttrium are certain rare elements, as erbium, ytterbium, samarium, etc., which are separated in a pure state with great difficulty. They are studied by means of their spark or phosphorescent spectra. Yttrium is now regarded as probably not a simple element, but as a mixture of several substances.</note><-- yttrium has been isolated as a pure element. --><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yttro-cerite</ent><br/
<hw>Yt`tro-ce"rite</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Min.)</fld> <def>A mineral of a violet-blue color, inclining to gray and white. It is a hydrous fluoride of cerium, yttrium, and calcium.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yttro-tantalite</ent><br/
<ent>Yttro-columbite</ent><br/
<mhw>{ <hw>Yt`tro-co*lum"bite</hw> <pr>(?)</pr>, <hw>Yt`tro-tan"ta*lite</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <fld>(Min.)</fld> <def>A tantalate of uranium, yttrium, and calcium, of a brown or black color.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yu</ent><br/
||<hw>Yu</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Chin.]</ety> <fld>(Min.)</fld> <def>Jade.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yucca</ent><br/
<hw>Yuc"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>See <er>Flicker</er>, <pos>n.</pos>, 2.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yucca</ent><br/
||<hw>Yuc"ca</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[NL., from <ets>Yuca</ets>, its name in St. Domingo.]</ety> <fld>(Bot.)</fld> <def>A genus of American liliaceous, sometimes arborescent, plants having long, pointed, and often rigid, leaves at the top of a more or less woody stem, and bearing a large panicle of showy white blossoms.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The species with more rigid leaves (as <spn>Yucca aloifolia</spn>, <spn>Yucca Treculiana</spn>, and <spn>Yucca baccata</spn>) are called <stype>Spanish bayonet</stype>, and one with softer leaves  (<spn>Yucca filamentosa</spn>) is called <stype>bear grass</stype>, and <stype>Adam's needle</stype>.</note><br/
[<source>1913 Webster</source>]</p>

<p><cs><col><b>Yucca moth</b></col> <fld>(Zool.)</fld>, <cd>a small silvery moth (<spn>Pronuba yuccasella</spn>) whose larvae feed on plants of the genus <gen>Yucca</gen>.</cd></cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yucca borer</ent><br/
<hw>Yuc"ca bor`er</hw>. <sd>(a)</sd> <def>A California boring weevil (<spn>Yuccaborus frontalis</spn>).</def> <sd>(b)</sd> <def>A large mothlike butterfly (<spn>Megathymus yuccae</spn>) of the family <fam>Megatimidae</fam>, whose larva bores in yucca roots.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yuck</ent><br/
<hw>Yuck</hw> <pr>(?)</pr>, <pos>v. i.</pos> <ety>[Cf. G. <ets>jucken</ets>, D. <ets>yeuken</ets>, <ets>joken</ets>.  See <er>Itch</er>.]</ety> <def>To itch.</def>  <mark>[Prov. Eng.]</mark>  <rj><au>Grose.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yuck</ent><br/
<hw>Yuck</hw>, <pos>v. t.</pos> <def>To scratch.</def>  <mark>[Prov. Eng.]</mark>  <rj><au>Wright.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>yuck</ent><br/
<hw>yuck</hw>, <pos>interj.</pos> <def>an interjection expressing repugnance or distaste.</def><br/
[<source>PJC</source>]</p>

<p><ent>yuck</ent><br/
<hw>yuck</hw> <pos>n.</pos> <def>a laugh; also, a joke or gag; -- usually used in the plural, <as>as, the skit got lots of <ex>yucks</ex></as>.</def> <mark>[slang]</mark><br/
<syn><b>Syn. --</b> laugh; gag; joke</syn><br/
[<source>PJC</source>]</p>

<p><ent>Yuckel</ent><br/
<hw>Yuck"el</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>Same as <er>Yockel</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>yuck factor</ent><br/
<hw>yuck factor</hw>, <pos>n.</pos> <def>a reaction of repugnance or distaste; -- used in discussion of acceptability of proposed new foods, medicines, etc. among potential consumers or patients.</def><br/
[<source>PJC</source>]</p>

<p><ent>yucky</ent><br/
<hw>yuck"y</hw>, <pos>a.</pos> <def>Repugnant or distasteful.</def> <mark>[slang]</mark><br/
<syn><b>Syn. --</b> disgusting, disgustful, distasteful, loathly, loathsome, repellent, repellant, repugnant, revolting.</syn><br/
[<source>PJC</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Yuen</ent><br/
<hw>Yu"en</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Zool.)</fld> <def>The crowned gibbon (<spn>Hylobates pileatus</spn>), native of Siam, Southern China, and the Island of Hainan. It is entirely arboreal in its habits, and has very long arms. the males are dark brown or blackish, with a caplike mass of long dark hair, and usually with a white band around the face. The females are yellowish white, with a dark spot on the breast and another on the crown. Called also <altname>wooyen</altname>, and <altname>wooyen ape</altname>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yufts</ent><br/
<hw>Yufts</hw> <pr>(?)</pr>, <pos>n.</pos> <ety>[Russ. <ets>iufte</ets>.]</ety> <def>Russia leather.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yuga</ent><br/
<ent>Yug</ent><br/
<mhw>{ <hw>Yug</hw> <pr>(?)</pr>, ||<hw>Yu"ga</hw> <pr>(?)</pr>, }</mhw> <pos>n.</pos> <ety>[Skr. <ets>yuga</ets> an age, a yoke.  See <er>Yoke</er>.]</ety> <fld>(Hindoo Cosmog.)</fld> <def>Any one of the four ages, <xex>Krita</xex>, or <xex>Satya</xex>, <xex>Treta</xex>, <xex>Dwapara</xex>, and <xex>Kali</xex>, into which the Hindoos divide the duration or existence of the world.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yugoslav</ent><br/
<hw>Yu"go*slav`</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <sn>1.</sn> <def>a native or inhabitant of Yugoslavia.</def><br/
<syn><b>Syn. --</b> Jugoslav, Yugoslavian, Jugoslavian.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yugoslav</ent><br/
<ent>Yugoslavian</ent><br/
<mhw><hw>Yu"go*slav</hw> <pr>(?)</pr>, <hw>Yugoslavian</hw></mhw> <pos>prop. adj.</pos>  <def>Of or pertaining to Yugoslavia; <as>as, <ex>Yugoslavian</ex> wine</as>.</def><br/
<syn><b>Syn. --</b> Yugoslavian, Jugoslav, Jugoslavian.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yugoslavian</ent><br/
<hw>Yu"go*sla`vi*an</hw> <pr>(?)</pr>, <pos>prop. n.</pos> <sn>1.</sn> <def>a native or inhabitant of Yugoslavia.</def><br/
<syn><b>Syn. --</b> Yugoslav, Jugoslav, Jugoslavian.</syn><br/
[<source>WordNet 1.5</source>]</p>

<p><ent>Yuke</ent><br/
<hw>Yuke</hw> <pr>(<umac/k)</pr>, <pos>v. i. & t.</pos> <def>Same as <er>Yuck</er>.</def>  <mark>[Prov. Eng.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yulan</ent><br/
<hw>Yu"lan</hw> <pr>(<umac/"l<acr/n)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>A species of Magnolia (<spn>Magnolia conspicua</spn>) with large white blossoms that open before the leaves.  See the Note under <er>Magnolia</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yule</ent><br/
<hw>Yule</hw> <pr>(<umac/l)</pr>, <pos>n.</pos> <ety>[OE. <ets>yol</ets>, <ets><yogh/ol</ets>, AS. <ets>ge<oacute/l</ets>; akin to <ets>ge<oacute/la</ets> December or January, Icel. <ets>j<omac/l</ets> Yule, <ets>Ylir</ets> the name of a winter month, Sw. <ets>jul</ets> Christmas, Dan. <ets>juul</ets>, Goth. <ets>jiuleis</ets> November or December.  Cf. <er>Jolly</er>.]</ety> <def>Christmas or Christmastide; the feast of the Nativity of our Savior.</def><br/
[<source>1913 Webster</source>]</p>

<p><q>And at each pause they kiss; was never seen such rule<br/
In any place but here, at bonfire, or at <qex>Yule</qex>.</q> <rj><qau>Drayton.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><cs><mcol><col><b>Yule block</b></col>, <it>or</it> <col><b>Yule log</b></col></mcol>, <cd>a large log of wood formerly put on the hearth on Christmas eve, as the foundation of the fire. It was brought in with much ceremony.</cd> -- <col><b>Yule clog</b></col>, <cd>the yule log.</cd>  <rj><au>Halliwell. W. Irving.</au></rj>
</cs><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yuletide</ent><br/
<hw>Yule"tide`</hw> <pr>(?)</pr>, <pos>n.</pos> <def>Christmas time; Christmastide; the season of Christmas.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yuman</ent><br/
<hw>Yu"man</hw> <pr>(?)</pr>, <pos>a.</pos> <def>Designating, or pertaining to, an important linguistic stock of North American Indians of the southwestern United States and northwestern Mexico, nearly all agriculturists and adept potters and basket makers. Their usual dwelling is the brush wikiup, and in their native state they wear little clothing. The Yuma, Maricopa, Mohave, Walapi, and Yavapai are among the chief tribes, all of fine physique.</def><br/
[<source>Webster 1913 Suppl.</source>]</p>

<p><ent>Yumas</ent><br/
<hw>Yu"mas</hw> <pr>(?)</pr>, <pos>n. pl.</pos>; <sing>sing. <singw>Yuma</singw> <pr>(<?/)</pr></sing>. <fld>(Ethnol.)</fld> <def>A tribe of Indians native of Arizona and the adjacent parts of Mexico and California. They are agricultural, and cultivate corn, wheat, barley, melons, etc.</def><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The a wider sense, the term sometimes includes the Mohaves and other allied tribes.</note><br/
[<source>1913 Webster</source>]</p>

<p><ent>yummy</ent><br/
<hw>yum"my</hw> <pr>(y<ucr/m"m<ycr/)</pr>, <pos>adj.</pos> <def>Very pleasing or attractive; especially, pleasing to the taste; delicious; scrumptious.</def> <mark>[colloq.]</mark> <br/
<syn><b>Syn. --</b> delectable, delicious, luscious, pleasant-tasting, scrumptious, toothsome.</syn><br/
[<source>PJC</source> + <source>WordNet 1.5</source>]</p>

<p><ent>Yunca</ent><br/
<hw>Yun"ca</hw> <pr>(y<oomac/<nsm/"k<adot/)</pr>, <pos>n.</pos> <def>An Indian of a linguistic stock of tribes of the Peruvian coast who had a developed agricultural civilization at the advent of the Spaniards, before which they had been conquered by the Incas. They constructed irrigation canals which are still in use, adorned their buildings with bas-reliefs and frescoes, and were skilled goldsmiths and silversmiths.</def> -- <wordforms><wf>Yun"can</wf> <pr>(?)</pr>, <pos>a.</pos></wordforms></p>

<p><ent>Yunx</ent><br/
||<hw>Yunx</hw> <pr>(y<ucr/<nsm/ks)</pr>, <pos>n.</pos> <ety>[NL., fr. Gr. <grk>'i`ygx</grk> the wryneck.]</ety> <fld>(Zool.)</fld> <def>A genus of birds comprising the wrynecks.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yupon</ent><br/
<hw>Yu"pon</hw> <pr>(?)</pr>, <pos>n.</pos> <fld>(Bot.)</fld> <def>Same as <er>Yaupon</er>.</def><br/
[<source>1913 Webster</source>]</p>

<p><ent>yuppy</ent><br/
<ent>yuppie</ent><br/
<mhw><hw>yup"pie</hw>, <hw>yup"py</hw></mhw> <pr>(y<ucr/p"p<ycr/)</pr>, <pos>n.</pos> <ety>[<ets>y</ets>oung <ets>u</ets>rban <ets>p</ets>rofessional + <ets>-ie</ets>.]</ety> <def>an ambitious young adult, usually college-educated, living in or near a large city, with a professional career and an affluent lifestyle.  The "u" in the word is sometimes interpreted as meaning <ldquo/upwardly mobile<rdquo/.</def><br/
[<source>PJC</source>]</p>

<p><ent>Yux</ent><br/
<hw>Yux</hw> <pr>(?)</pr>, <pos>n. & v.</pos> <def>See <er>Yex</er>, <pos>n.</pos></def> <mark>[Obs.]</mark><br/
[<source>1913 Webster</source>]</p>

<p><ent>Yvel</ent><br/
<hw>Y"vel</hw> <pr>(?)</pr>, <pos>a. & adv.</pos> <def>Evil; ill.</def>  <mark>[Obs.]</mark>  <rj><au>Chaucer.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ywar</ent><br/
<hw>Y*war"</hw> <pr>(?)</pr>, <pos>a.</pos> <ety>[See <er>Aware</er>.]</ety> <def>Aware; wary.</def>  <mark>[Obs.]</mark> <ldquo/Be <xex>ywar</xex>, and his way shun.<rdquo/  <rj><au>Piers Plowman.</au></rj><br/
[<source>1913 Webster</source>]</p>

<p><ent>Ywis</ent><br/
<hw>Y*wis"</hw> <pr>(?)</pr>, <pos>adv.</pos> <ety>[OE. <ets>ywis</ets>, <ets>iwis</ets>, AS. <ets>gewis</ets> certain; akin to D. <ets>gewis</ets>, G. <ets>gewiss</ets>, and E. <ets>wit</ets> to know.  See <er>Wit</er> to know, and <er>Y-</er>.]</ety> <def>Certainly; most likely; truly; probably.</def>  <mark>[Obs. or Archaic]</mark><br/
[<source>1913 Webster</source>]</p>

<p><q><ldquo/<qex>Ywis</qex>,<rdquo/ quod he, <ldquo/it is full dear, I say.<rdquo/</q> <rj><qau>Chaucer.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>She answered me, <ldquo/<qex>I-wisse</qex>, all their sport in the park is but a shadow to that pleasure that I find in Plato.<rdquo/</q> <rj><qau>Ascham.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><q>A right good knight, and true of word <qex>ywis</qex>.</q> <rj><qau>Spenser.</qau></rj><br/
[<source>1913 Webster</source>]</p>

<p><note><hand/ The common form <xex>iwis</xex> was often written with the prefix apart from the rest of the word and capitalized, as, <xex>I wis</xex>, <xex>I wisse</xex>, etc. The prefix was mistaken for the pronoun, <xex>I</xex> and <xex>wis</xex>, <xex>wisse</xex>, for a form of the verb <xex>wit</xex> to know.  See <er>Wis</er>, and cf. <er>Wit</er>, to know.</note><br/
[<source>1913 Webster</source>]</p>

<p><q>Our ship, <qex>I wis</qex>,<br/
Shall be of another form than this.</q> <rj><qau>Longfellow.</qau></rj><br/
[<source>1913 Webster</source>]</p>

